% ESTIMATORS FOR AGRICULTURAL DYNAMIC LAND USE CHOICE MODEL

rng(12345)

% note that "partial" here means using the ccp and v moments
% "hybrid" means estimating sigma like ccp, then using v moments to recover intercepts

tic

% Datafolder
datafolder = 'C:/Users/ptsco/Dropbox/land_values/Output/';
outfolder  = 'C:/Users/ptsco/Dropbox/land_values/Output/';

%datafolder = '/data/landvalues/interim/';
%outfolder = '/data/landvalues/results/';

%datafolder = 'C:\Users\souzarod\Dropbox\land_values\Output\';
%outfolder = 'C:\Users\souzarod\Dropbox\land_values\Output\';

%datafolder = 'C:\Users\Edumarf\Dropbox\land_values\Output\';
%outfolder = 'C:\Users\Edumarf\Dropbox\land_values\Output\';


% Options
options = optimset('Display','off','TolX',1e-13,'TolFun',1e-13,'MaxIter',200,'MaxFunEvals',500);

% Specify set up
if ~exist('g')
	g = 2;
end
if ~exist('cp')
	cp = 2;
end
if ~exist('soil')
	soil = 1;
end
if ~exist('vdep')
	vdep = 1;
end
if ~exist('acres')
	acres = 1;
end
if ~exist('hdum')
	hdum = 1;
end
if ~exist('hz')
	hz = 1;
end
if ~exist('pyear')
	pyear = 1;
end
if ~exist('ivspec')
	ivspec = 0;
end
if ~exist('constant')
	constant = 0;
end
if ~exist('ser')
	ser = 1;
end

% Specify Data
infile = [datafolder, 'estimation_data.grid', num2str(g), '.ccp', num2str(cp), '.soil', num2str(soil), '.vdep', num2str(vdep), '.acres', num2str(acres), '.hdum', num2str(hdum), '.hz', num2str(hz), '.py', num2str(pyear), '.raw']

% if ~exist(outfile3)

% Load Data
data = importdata(infile);

% Variables
dyccp   = data(:,1);
dyvc    = data(:,2);
dyvnc   = data(:,3);
dr      = data(:,4);
lr      = data(:,5);
dpsic   = data(:,6);
dpsinc  = data(:,7);
lpsic   = data(:,8);
lpsinc  = data(:,9);
caly    = data(:,10)/1000000;
fid     = data(:,11);
k       = data(:,12);
Yccp    = data(:,13);
Yvc     = data(:,14);
Yvnc    = data(:,15);
psic    = data(:,16);
psinc   = data(:,17);
Rc      = data(:,18);
Rnc     = data(:,19);
year    = data(:,20);
wt      = data(:,21);
slope   = data(:,22);
l2r     = data(:,23);
l2psic  = data(:,24);
l2psinc = data(:,25);
county  = data(:,26);

% Size of Data
NN = size(data,1);

% Clear data
clear data;

% Identify Years and Fields
yrs    = unique(year);
fields = unique(fid);

% trim large weights
%wt(wt>50) = 50;

% Discount Factor
beta = 0.95;

% Observations to keep using standard instruments
drop = isnan(dyccp) + isnan(lpsinc) + isnan(lpsic) + isnan(psinc) + isnan(psic) + isnan(Yccp);
keep = drop==0;

% Observations to keep when using double lags
drop2 = drop + isnan(l2psic) + isnan(l2psinc);
keep2 = drop2==0;

% backup full values of variables
Rc_full         = Rc;
Rnc_full		= Rnc;
lr_full         = lr;
dr_full         = dr;
Yvc_full        = Yvc;
Yvnc_full       = Yvnc;
dyvc_full       = dyvc;
dyvnc_full      = dyvnc;
Yccp_full       = Yccp;
psic_full       = psic;
psinc_full      = psinc;
lpsic_full      = lpsic;
lpsinc_full     = lpsinc;
dyccp_full      = dyccp;
dpsic_full      = dpsic;
dpsinc_full     = dpsinc;
wt_full         = wt;
l2psic_full     = l2psic;
l2psinc_full    = l2psinc;
l2r_full        = l2r;
caly_full		= caly;
slope_full 		= slope;
county_full     = county;

% Select Data used for estimation (avoid 'NaN' cases)
if (ivspec == 1) || (ivspec == 2)
	Rc         = Rc(keep2);
	Rnc 	   = Rnc(keep2);
	lr         = lr(keep2);
	dr         = dr(keep2);
	Yvc        = Yvc(keep2);
	Yvnc       = Yvnc(keep2);
	dyvc       = dyvc(keep2);
	dyvnc      = dyvnc(keep2);
	Yccp       = Yccp(keep2);
	psic       = psic(keep2);
	psinc      = psinc(keep2);
	lpsic      = lpsic(keep2);
	lpsinc     = lpsinc(keep2);
	dyccp      = dyccp(keep2);
	dpsic      = dpsic(keep2);
	dpsinc     = dpsinc(keep2);
	wt 		   = wt(keep2);
	l2psic     = l2psic(keep2);
	l2psinc    = l2psinc(keep2);
	l2r        = l2r(keep2);
	caly	   = caly(keep2);
	slope 	   = slope(keep2);
    county     = county(keep2);
	N          = sum(keep2);
else
	Rc         = Rc(keep);
	Rnc 	   = Rnc(keep);
	lr         = lr(keep);
	dr         = dr(keep);
	Yvc        = Yvc(keep);
	Yvnc       = Yvnc(keep);
	dyvc       = dyvc(keep);
	dyvnc      = dyvnc(keep);
	Yccp       = Yccp(keep);
	psic       = psic(keep);
	psinc      = psinc(keep);
	lpsic      = lpsic(keep);
	lpsinc     = lpsinc(keep);
	dyccp      = dyccp(keep);
	dpsic      = dpsic(keep);
	dpsinc     = dpsinc(keep);
	wt 		   = wt(keep);
	l2psic     = l2psic(keep);
	l2psinc    = l2psinc(keep);
	l2r        = l2r(keep);
	caly	   = caly(keep);
	slope  	   = slope(keep);
    county     = county(keep);
	N          = sum(keep);
end

% Differences in returns for crops vs. other
Rdif      = Rc - Rnc;
Rdif_full = Rc_full - Rnc_full;

% Number of Time Periods
TT = max(year(keep)) - min(year(keep)) + 1;

% Number of Fields in the selected data
Nf = length(unique(fid(keep)));

% Weighted Variables (using 'weights')
Rcw         = (sqrt(wt)).*Rc;
Rncw        = (sqrt(wt)).*Rnc;
Rdifw       = (sqrt(wt)).*(Rc - Rnc);
lrw         = (sqrt(wt)).*lr;
drw         = (sqrt(wt)).*dr;
Yvcw        = (sqrt(wt)).*Yvc;
Yvncw       = (sqrt(wt)).*Yvnc;
dyvcw       = (sqrt(wt)).*dyvc;
dyvncw      = (sqrt(wt)).*dyvnc;
Yccpw       = (sqrt(wt)).*Yccp;
psicw       = (sqrt(wt)).*psic;
psincw      = (sqrt(wt)).*psinc;
lpsicw      = (sqrt(wt)).*lpsic;
lpsincw     = (sqrt(wt)).*lpsinc;
dyccpw      = (sqrt(wt)).*dyccp;
dpsicw      = (sqrt(wt)).*dpsic;
dpsincw     = (sqrt(wt)).*dpsinc;
l2psicw     = (sqrt(wt)).*l2psic;
l2psincw    = (sqrt(wt)).*l2psinc;
l2rw        = (sqrt(wt)).*l2r;
consw       = (sqrt(wt)).*ones(N,1);
calyw	    = (sqrt(wt)).*caly;
slopew 		= (sqrt(wt)).*slope;

% Sum of weights
Nw   = sum(wt);

% Interaction Terms (for IV)
sloper      = slope .*lr;
sloperw     = slopew.*lr;
sloper_full = slope_full.*lr_full;

% Covariates
if constant == 0
	x_ccp 	= dr;
	x_vc	= dpsic;
	x_vnc 	= dpsinc;
	% weighted
	xw_ccp 	= drw;
	xw_vc	= dpsicw;
	xw_vnc 	= dpsincw;
elseif constant == 1
	x_ccp 	= [ones(N,1), dr];
	x_vc	= [ones(N,1), dpsic];
	x_vnc 	= [ones(N,1), dpsinc];
	% weighted
	xw_ccp 	= [consw, drw];
	xw_vc	= [consw, dpsicw];
	xw_vnc 	= [consw, dpsincw];
end

% Full covariates for v
xv  = [x_vc;  x_vnc];
xvw = [xw_vc; xw_vnc];

% Covariates in the full data
if constant == 0
	x_ccp_full 	= dr_full;
	x_vc_full	= dpsic_full;
	x_vnc_full 	= dpsinc_full;
elseif contant == 1
	x_ccp_full 	= [ones(NN,1), dr_full];
	x_vc_full	= [ones(NN,1), dpsic_full];
	x_vnc_full 	= [ones(NN,1), dpsinc_full];
end

% Instrumental Variables
if ivspec == 0
    zccp  = [ones(N,1), lr/100,     caly];
    zvc   = [ones(N,1), lpsic,  caly];
    zvnc  = [ones(N,1), lpsinc, caly];
    zccp_full  = [ones(NN,1), lr_full/100,     caly_full];
    zvc_full   = [ones(NN,1), lpsic_full,  caly_full];
    zvnc_full  = [ones(NN,1), lpsinc_full, caly_full];
    % Weighted
    zccpw  = [consw, lrw/100,     calyw];
    zvcw   = [consw, lpsicw,  calyw];
    zvncw  = [consw, lpsincw, calyw];
elseif ivspec == 1
    zccp = [ones(N,1), lr/100,      caly];
    zvc  = [ones(N,1), l2psic,  caly];
    zvnc = [ones(N,1), l2psinc, caly];
	zccp_full = [ones(NN,1), lr_full/100,      caly_full];
    zvc_full  = [ones(NN,1), l2psic_full,  caly_full];
    zvnc_full = [ones(NN,1), l2psinc_full, caly_full];
    % Weighted
    zccpw = [consw, lrw/100,      calyw];
    zvcw  = [consw, l2psicw,  calyw];
    zvncw = [consw, l2psincw, calyw];
elseif ivspec == 2
    zccp = [ones(N,1), l2r/100,     caly];
    zvc  = [ones(N,1), l2psic,  caly];
    zvnc = [ones(N,1), l2psinc, caly];
	zccp_full = [ones(NN,1), l2r_full/100,     caly_full];
    zvc_full  = [ones(NN,1), l2psic_full,  caly_full];
    zvnc_full = [ones(NN,1), l2psinc_full, caly_full];
    % Weighted
    zccpw = [consw, l2rw/100,     calyw];
    zvcw  = [consw, l2psicw,  calyw];
    zvncw = [consw, l2psincw, calyw];
end

zccps = [zccp slope];
zvcs  = [zvc  slope];
zvncs = [zvnc slope];
zccps_full = [zccp_full slope_full];
zvcs_full  = [zvc_full  slope_full];
zvncs_full = [zvnc_full slope_full];
zccpsw = [zccpw  slopew];
zvcsw  = [zvcw   slopew];
zvncsw = [zvncw  slopew];

% Full Instruments for V
zv  = [zvc ; zvnc];
zvw = [zvcw; zvncw];

% V Dependent Variable
dyyv   = [dyvc ; dyvnc];
dyyvw  = [dyvcw; dyvncw];


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  ESTIMATION  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%------------------ Estimate Sigmas ---------------------------------------

% 1. MODELS WITH NO SLOPE


% (a) CCP 2SLS weighted - no slope
wwccpw        = inv(zccpw'*zccpw/Nw);
thetaRw2sls   = ((xw_ccp'*zccpw*wwccpw*zccpw'*xw_ccp)\(xw_ccp'*zccpw*wwccpw*zccpw'))*dyccpw;
sigmaccpw2sls = 1/thetaRw2sls;

% (b) VFN 2SLS weighted - no slope
%wwvw       = inv(zvw'*zvw/Nw);
%sigmavwgmm = ((xvw'*zvw*wwvw*zvw'*xvw)\(xvw'*zvw*wwvw*zvw'))*dyyvw;

% Starting values for sigma
starting_vals = [100,500,1500,5000]';
starting_vals = ones(size(starting_vals,1),1)./starting_vals;

% (c) CCP - no slope
Sccp = zccpw'*zccpw/Nw;
Wccp = inv(Sccp);
[theta1_ccp_w objval sig_hist_ccp_w Wopt_ccpw] = twostage_gmm(starting_vals,dyccp,dyvc,dyvnc, ...
	x_ccp,x_vc,x_vnc,zccp,zvc,zvnc,dyccp_full,dyvc_full,dyvnc_full,x_ccp_full, ...
	x_vc_full,x_vnc_full,zccp_full,zvc_full,zvnc_full,fid,k,year,TT,Wccp,wt,wt_full,slope,slope_full,keep, ...
	1,1,ser);
sigma_ccp_w = 1/theta1_ccp_w;

%vals = (10:(10):5000)';
%objvals = zeros(size(vals,1),1);
%for i = 1:length(vals)
%	objvals(i) = gmm_obj_full(1/vals(i),dyccp,dyvc,dyvnc,x_ccp, ...
%							x_vc,x_vnc,zccp,zvc,zvnc,inv(Sccp),sqrt(wt),slope,1,1);
%end


% (d) Partial - no slope
Wpart = [inv(zccpw'*zccpw/Nw), zeros(size(zccpw,2),size(zvcw,2)); zeros(size(zvcw,2),size(zccpw,2)),inv(zvcw'*zvcw/Nw)];
[theta1_part_w objval sig_hist_part_w Wopt_partw] = twostage_gmm(starting_vals,dyccp,dyvc,dyvnc, ...
	x_ccp,x_vc,x_vnc,zccp,zvc,zvnc,dyccp_full,dyvc_full,dyvnc_full,x_ccp_full, ...
	x_vc_full,x_vnc_full,zccp_full,zvc_full,zvnc_full,fid,k,year,TT,Wpart,wt,wt_full,slope,slope_full,keep, ...
	4,1,ser);
sigma_part_w = 1/theta1_part_w;




% 2. MODELS WITH SLOPE

% Starting values for theta with slope
starting_theta = [[-20 -5 -2 0 2 5 20]' zeros(7,1)];

% (a) CCP - slope
Wccps = inv(zccpsw'*zccpsw/Nw);
[theta1_ccp_ws objval sig_hist_ccp_ws Wopt_ccpws] = twostage_gmm(starting_theta,dyccp,dyvc,dyvnc, ...
	x_ccp,x_vc,x_vnc,zccps,zvcs,zvncs,dyccp_full,dyvc_full,dyvnc_full,x_ccp_full, ...
	x_vc_full,x_vnc_full,zccps_full,zvcs_full,zvncs_full,fid,k,year,TT,Wccps,wt,wt_full,slope,slope_full,keep, ...
	1,2,ser);

% (b) Partial - slope
%Wparts = [inv(zccpsw'*zccpsw/Nw), zeros(size(zccpsw,2),size(zvcsw,2)); zeros(size(zvcsw,2),size(zccpsw,2)),inv(zvcsw'*zvcsw/Nw)];
Wparts = eye(size(zccpsw,2)+size(zvcsw,2),size(zccpsw,2)+size(zvcsw,2));
[theta1_part_ws objval sig_hist_part_ws Wopt_partws] = twostage_gmm(starting_theta,dyccp,dyvc,dyvnc, ...
	x_ccp,x_vc,x_vnc,zccps,zvcs,zvncs,dyccp_full,dyvc_full,dyvnc_full,x_ccp_full, ...
	x_vc_full,x_vnc_full,zccps_full,zvcs_full,zvncs_full,fid,k,year,TT,Wparts,wt,wt_full,slope,slope_full,keep, ...
	4,2,ser);


% Sigmas for models with slope
sigma_ccp_ws       = exp(theta1_ccp_ws(1)  + theta1_ccp_ws(2)*slope);
sigma_ccp_ws_full  = exp(theta1_ccp_ws(1)  + theta1_ccp_ws(2)*slope_full);
sigma_part_ws      = exp(theta1_part_ws(1) + theta1_part_ws(2)*slope);
sigma_part_ws_full = exp(theta1_part_ws(1) + theta1_part_ws(2)*slope_full);

%sigma_v_ws          = exp(theta1_v_ws(1)     + theta1_v_ws(2)*slope);
%sigma_v_ws_full     = exp(theta1_v_ws(1)     + theta1_v_ws(2)*slope_full);
%sigma_joint_ws      = exp(theta1_joint_ws(1) + theta1_joint_ws(2)*slope);
%sigma_joint_ws_full = exp(theta1_joint_ws(1) + theta1_joint_ws(2)*slope_full);

disp('SIGMAS');
sigma_ccp_w
sigma_part_w
median(sigma_ccp_ws)
median(sigma_part_ws)



%------------------ (Differenced) Residuals ---------------------------------------

% 1. MODELS WITH NO SLOPE

% Residuals using ccp sigma
epsccp_ccpw     =  dyccp_full - dr_full/sigma_ccp_w;
epsvc_ccpw  = dyvc_full  - dpsic_full  * sigma_ccp_w;
epsvnc_ccpw = dyvnc_full - dpsinc_full * sigma_ccp_w;

% residuals using partial sigma
epsccp_partialw =  dyccp_full - dr_full/sigma_part_w;
epsvc_partialw  = dyvc_full  - dpsic_full  * sigma_part_w;
epsvnc_partialw = dyvnc_full - dpsinc_full * sigma_part_w;


% 2. MODELS WITH SLOPE

% Residuals using ccp sigma
epsccp_ccpws     =  dyccp_full - dr_full./sigma_ccp_ws_full;
epsvc_ccpws  = dyvc_full  - dpsic_full  .* sigma_ccp_ws_full;
epsvnc_ccpws = dyvnc_full - dpsinc_full .* sigma_ccp_ws_full;

% residuals using partial sigma
epsccp_partialws	= dyccp_full - dr_full./sigma_part_ws_full;
epsvc_partialws	= dyvc_full  - dpsic_full  .* sigma_part_ws_full;
epsvnc_partialws	= dyvnc_full - dpsinc_full .* sigma_part_ws_full;


%------------------ Standard Errors for Sigmas-----------------------------

disp('CALCULATING STANDARD ERRORS FOR SIGMAS');

% (a) CCP - no slope
% Derivatives of moments:
G_ccp = calcG(theta1_ccp_w,dr,x_vc,x_vnc,zccp,zvc,zvnc,wt,slope,1,1);

% Variance of moments:
g_ccp = zccp_full.*epsccp_ccpw(:,ones(size(zccp_full,2),1));
S_ccp = calcS3(g_ccp,fid,k,year,wt_full,keep,TT);


% Asymptotic covariance matrix of coefficients:
vcmat_ccp = gmm_avar(G_ccp,S_ccp,Wopt_ccpw);
vcmat_ccp = vcmat_ccp/N*TT/(TT-1);
sqrt(vcmat_ccp)

% no clustering
S_ccp_nc = calcS_alt(g_ccp,fid,k,year,wt_full,keep,TT);
vcmat_ccp_nc = gmm_avar(G_ccp,S_ccp_nc,Wopt_ccpw);
vcmat_ccp_nc = vcmat_ccp_nc/N;

% Use Delta Method to get Var-Cov for Sigma
vcmat_ccp_sigma = (sigma_ccp_w)^4 * vcmat_ccp;
vcmat_ccp_sigma_nc = (sigma_ccp_w)^4 * vcmat_ccp_nc;

disp('CCP - no slope: sigma, std error and t-stat');
sigma_ccp_w
sqrt(vcmat_ccp_sigma)
t_ccp_w = (sigma_ccp_w)/sqrt(vcmat_ccp_sigma)


% (b) Partial - no slope
G_partial     = calcG(theta1_part_w,dr,x_vc,x_vnc,zccp,zvc,zvnc,wt,slope,4,1);
g_partial1    = zccp_full.*epsccp_partialw(:,ones(size(zccp_full,2),1));
g_partial2    = zvc_full .*epsvc_partialw(:,ones(size(zvc_full,2),1));
g_partial     = [g_partial1, g_partial2];
S_partial     = calcS3(g_partial,fid,k,year,wt_full,keep,TT);
vcmat_partial = gmm_avar(G_partial,S_partial,Wopt_partw);
vcmat_partial = vcmat_partial/N*TT/(TT-1);
sqrt(vcmat_partial)
% Use Delta Method to get Var-Cov for Sigma
vcmat_part_sigma = (sigma_part_w)^4 * vcmat_partial;
disp('Partial - no slope: sigma, std error and t-stat');
sigma_part_w
sqrt(vcmat_part_sigma)
t_part_w = (sigma_part_w)/sqrt(vcmat_part_sigma)


% (c) CCP - slope (OBS: THESE ARE STD ERRORS FOR GAMMA0,GAMMA1. NEED STD ERROR FOR MEAN SIGMA)
G_ccps     = calcG(theta1_ccp_ws,dr,x_vc,x_vnc,zccps,zvcs,zvncs,wt,slope,1,2);
g_ccps     = zccps_full.*epsccp_ccpws(:,ones(size(zccps_full,2),1));
S_ccps     = calcS3(g_ccps,fid,k,year,wt_full,keep,TT);
vcmat_ccps = gmm_avar(G_ccps,S_ccps,Wopt_ccpws);
vcmat_ccps = vcmat_ccps/N*TT/(TT-1);
disp('CCP - with slope: theta1, std error and t-stat');
theta1_ccp_ws'
sqrt(diag(vcmat_ccps))
t_ccp_ws = theta1_ccp_ws'./sqrt(diag(vcmat_ccps))


% (d) Partial - slope (OBS: THESE ARE STD ERRORS FOR GAMMA0,GAMMA1. NEED STD ERROR FOR MEAN SIGMA)
G_partials     = calcG(theta1_part_ws,dr,x_vc,x_vnc,zccps,zvcs,zvncs,wt,slope,4,2);
g_partials1    = zccps_full.*epsccp_partialws(:,ones(size(zccps_full,2),1));
g_partials2    = zvcs_full.*epsvc_partialws(:,ones(size(zvcs_full,2),1));
g_partials     = [g_partials1, g_partials2];
S_partials     = calcS3(g_partials,fid,k,year,wt_full,keep,TT);
vcmat_partials = gmm_avar(G_partials,S_partials,Wopt_partws);
vcmat_partials = vcmat_partials/N*TT/(TT-1);
disp('Partial - with slope: theta1, std error and t-stat');
theta1_part_ws'
sqrt(diag(vcmat_partials))
t_part_ws = theta1_part_ws'./sqrt(diag(vcmat_partials))


%------------------ Non-differenced Residuals ---------------------------------------

% 1. MODELS WITH NO SLOPE

% Residuals using ccp sigma
resJccpw     = sigma_ccp_w * Yccp_full - Rdif_full;
resJvc_ccpw  = Yvc_full  - psic_full  * sigma_ccp_w;
resJvnc_ccpw = Yvnc_full - psinc_full * sigma_ccp_w;

% residuals using partial sigma
resJccp_partialw = sigma_part_w * Yccp_full - Rdif_full;
resJvc_partialw  = Yvc_full  - psic_full  * sigma_part_w;
resJvnc_partialw = Yvnc_full - psinc_full * sigma_part_w;


% 2. MODELS WITH SLOPE

% Residuals using ccp sigma
resJccpws     = sigma_ccp_ws_full .* Yccp_full - Rdif_full;
resJvc_ccpws  = Yvc_full  - psic_full  .* sigma_ccp_ws_full;
resJvnc_ccpws = Yvnc_full - psinc_full .* sigma_ccp_ws_full;

% residuals using partial sigma
resJccp_partialws	= sigma_part_ws_full .* Yccp_full - Rdif_full;
resJvc_partialws	= Yvc_full  - psic_full  .* sigma_part_ws_full;
resJvnc_partialws	= Yvnc_full - psinc_full .* sigma_part_ws_full;



%------------------ Estimate Thetas ---------------------------------------

disp('ESTIMATING INTERCEPTS - THETAS');

% Matrices to map from regression intercepts and payoff intercepts
% the idea is res = M*theta, with different versions of res for
% the different estimators
Mccp     = 	[1+beta, -beta, 0;	...
			 beta, 1, -beta;	...
			 beta, 0, 1-beta];
Mjustc   = 	[eye(3), zeros(3,3); Mccp, -eye(3)];
Mjustnc  = 	[zeros(3,3), eye(3); Mccp, -eye(3)];
Mfull    = 	[eye(6); Mccp, -eye(3)];

% average residuals by field
avres_ccpw 			= getavres(resJccpw,fid,k,year,keep);
avres_ccp_vcw		= getavres(resJvc_ccpw,fid,k,year,keep);
avres_ccp_vncw		= getavres(resJvnc_ccpw,fid,k,year,keep);
avres_partial_ccpw	= getavres(resJccp_partialw,fid,k,year,keep);
avres_partial_vcw	= getavres(resJvc_partialw,fid,k,year,keep);
avres_partial_vncw	= getavres(resJvnc_partialw,fid,k,year,keep);
%avres_vcw  			= getavres(resJvcw,fid,k,year,keep);
%avres_vncw 			= getavres(resJvncw,fid,k,year,keep);
%avres_joint_ccpw  	= getavres(resJccp_jointw,fid,k,year,keep);
%avres_joint_vcw		= getavres(resJvc_jointw,fid,k,year,keep);
%avres_joint_vncw	= getavres(resJvnc_jointw,fid,k,year,keep);

% average residuals by field for models with slope
avres_ccpws 		= getavres(resJccpws,fid,k,year,keep);
avres_ccp_vcws		= getavres(resJvc_ccpws,fid,k,year,keep);
avres_ccp_vncws		= getavres(resJvnc_ccpws,fid,k,year,keep);
avres_partial_ccpws	= getavres(resJccp_partialws,fid,k,year,keep);
avres_partial_vcws	= getavres(resJvc_partialws,fid,k,year,keep);
avres_partial_vncws	= getavres(resJvnc_partialws,fid,k,year,keep);
%avres_vcws  		= getavres(resJvcws,fid,k,year,keep);
%avres_vncws 		= getavres(resJvncws,fid,k,year,keep);
%avres_joint_ccpws  	= getavres(resJccp_jointws,fid,k,year,keep);
%avres_joint_vcws	= getavres(resJvc_jointws,fid,k,year,keep);
%avres_joint_vncws	= getavres(resJvnc_jointws,fid,k,year,keep);

% recover profit function intercepts
theta_ccpw 	   = (inv(Mccp)*avres_ccpw')';
theta_ccpw     = [theta_ccpw, zeros(size(theta_ccpw,1),3)];
theta_justcw   = (inv(Mjustc)*[avres_ccp_vcw,avres_ccpw]')';
theta_partialw = (inv(Mjustc)*[avres_partial_vcw,avres_partial_ccpw]')';
%theta_vw 	   = [avres_vcw, avres_vncw];
%theta_justncw  = (inv(Mjustnc)*[avres_ccp_vncw,avres_ccpw]')';
%theta_jointw    = (inv(Mfull'*Mfull)*Mfull'*[avres_joint_vcw,avres_joint_vncw,avres_joint_ccpw]')';

theta_ccpws		= (inv(Mccp)*avres_ccpws')';
theta_ccpws     = [theta_ccpws, zeros(size(theta_ccpws,1),3)];
theta_justcws   = (inv(Mjustc)*[avres_ccp_vcws,avres_ccpws]')';
theta_partialws	= (inv(Mjustc)*[avres_partial_vcws,avres_partial_ccpws]')';
%theta_vws		= [avres_vcws, avres_vncws];
%theta_justncws  = (inv(Mjustnc)*[avres_ccp_vncws,avres_ccpws]')';
%theta_jointws	= (inv(Mfull'*Mfull)*Mfull'*[avres_joint_vcws,avres_joint_vncws,avres_joint_ccpws]')';


% STANDARD ERRORS FOR MEAN INTERCEPTS - ONLY MODEL WITH NO SLOPE
disp('STANDARD ERRORS ON INTERCEPTS');
nsim = 100;
[theta0_ccp_sim theta0_hybrid_sim] = interceptSE(theta1_ccp_w,vcmat_ccp, ...
			Yccp_full,Yvc_full,Yvnc_full,Rdif_full,psic_full,psinc_full, ...
			slope_full,fid,k,year,keep,Mccp,Mjustc,nsim);

[temp theta0_part_sim] = interceptSE(theta1_part_w,vcmat_partial, ...
			Yccp_full,Yvc_full,Yvnc_full,Rdif_full,psic_full,psinc_full, ...
			slope_full,fid,k,year,keep,Mccp,Mjustc,nsim);

se_theta0_ccp    = sqrt(diag(cov(theta0_ccp_sim)));
se_theta0_hybrid = sqrt(diag(cov(theta0_hybrid_sim)));
se_theta0_part   = sqrt(diag(cov(theta0_part_sim)));

% 90% confidence intervals for sigma
sigma_ccp_w_975 = 	norminv(.975,sigma_ccp_w,sqrt(vcmat_ccp_sigma));
sigma_ccp_w_025 = 	norminv(.025,sigma_ccp_w,sqrt(vcmat_ccp_sigma));
sigma_part_w_975 = 	norminv(.975,sigma_part_w,sqrt(vcmat_part_sigma));
sigma_part_w_025 = 	norminv(.025,sigma_part_w,sqrt(vcmat_part_sigma));

% 90% confidence intervals for intercepts
theta0_975_ccp = 	quantile(theta0_ccp_sim,.975);
theta0_975_hybrid = 	quantile(theta0_hybrid_sim,.975);
theta0_975_part = 	quantile(theta0_part_sim,.975);

theta0_025_ccp = 		quantile(theta0_ccp_sim,.025);
theta0_025_hybrid = 	quantile(theta0_hybrid_sim,.025);
theta0_025_part = 	quantile(theta0_part_sim,.025);


% Show Results
disp('CCP - No Slope: mean theta, its std error, and t-stat');
mean(theta_ccpw)
se_theta0_ccp'
mean(theta_ccpw)./se_theta0_ccp'
disp('Hybrid - No Slope: mean theta, its std error, and t-stat');
mean(theta_justcw)
se_theta0_hybrid'
mean(theta_justcw)./se_theta0_hybrid'
disp('Partial - No Slope: mean theta, its std error, and t-stat');
mean(theta_partialw)
se_theta0_part'
mean(theta_partialw)./se_theta0_part'

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%  COUNTERFACTUALS  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp('STARTING COUNTERFACTUALS');

% Transition Matrix
% Crops
Fk1 = [1,0,0; ...
       1,0,0; ...
       1,0,0];
% Non-crops
Fk2 = [0,1,0; ...
       0,0,1; ...
       0,0,1];
% Join Matrices for crop/non-crop
Fk  = zeros(3,3,2);
Fk(:,:,1) = Fk1;
Fk(:,:,2) = Fk2;
% Degenerate Transition for Crop's Return
Fw = 1;


% -------------------------------------------------
% discretize the type space

% we only need sigma for each field, not each obs
sigma_ccp_ws_field  = getavres(sigma_ccp_ws_full,fid,k,year,keep);
sigma_ccp_ws_field  = sigma_ccp_ws_field(:,1);
sigma_part_ws_field = getavres(sigma_part_ws_full,fid,k,year,keep);
sigma_part_ws_field = sigma_part_ws_field(:,1);

% Average R's by field
avRc    = getavres(Rc_full,fid,k,year,keep);
avRnc   = getavres(Rnc_full,fid,k,year,keep);
avRdiff = getavres(Rdif_full,fid,k,year,keep);


Nfield = size(theta_ccpw,1);


% -------------------------------------------------
% Fertilizer Tax

disp('Fertilizer tax');

[cf2_ccpw  muC muA badobs1]			= RotSub(theta_ccpw,sigma_ccp_w,beta,avRc,avRnc,Fw,Fk,zeros(Nfield,3));
[cf2_justcw  muC muA badobs2]	    = RotSub(theta_justcw,sigma_ccp_w,beta,avRc,avRnc,Fw,Fk,zeros(Nfield,3));
[cf2_partialw  muC muA badobs3]		= RotSub(theta_partialw,sigma_part_w,beta,avRc,avRnc,Fw,Fk,zeros(Nfield,3));
badobs = max(badobs1,badobs2);
badobs = max(badobs,badobs3);
cf2_ccpw 		= RotSub(theta_ccpw,sigma_ccp_w,beta,avRc,avRnc,Fw,Fk,badobs);
cf2_justcw 		= RotSub(theta_justcw,sigma_ccp_w,beta,avRc,avRnc,Fw,Fk,badobs);
cf2_partialw 	= RotSub(theta_partialw,sigma_part_w,beta,avRc,avRnc,Fw,Fk,badobs);


%cf2_ccpws	 	= EntryTax(theta_ccpws,sigma_ccp_ws_field,beta,avRc,avRnc,Fw,Fk);
%cf2_justcws 	= EntryTax(theta_justcws,sigma_ccp_ws_field,beta,avRc,avRnc,Fw,Fk);
%cf2_partialws 	= EntryTax(theta_partialws,sigma_part_ws_field,beta,avRc,avRnc,Fw,Fk);


disp('FERTILIZER TAX - NO SLOPE');
cf2_ccpw
cf2_justcw
cf2_partialw
%disp('ENTRY TAX - SLOPE');
%cf2_ccpws
%cf2_justcws
%cf2_partialws

% -------------------------------------------------
% LRE

disp('LRE');


[cf3_ccpw muC muA badobs1]		= LRE(theta_ccpw,sigma_ccp_w,beta,avRc,avRnc,Fw,Fk,zeros(Nfield,3));
[cf3_justcw muC muA badobs2]	= LRE(theta_justcw,sigma_ccp_w,beta,avRc,avRnc,Fw,Fk,zeros(Nfield,3));
[cf3_partialw muC muA badobs3]	= LRE(theta_partialw,sigma_part_w,beta,avRc,avRnc,Fw,Fk,zeros(Nfield,3));
badobs = max(badobs1,badobs2);
badobs = max(badobs,badobs3);
cf3_ccpw		= LRE(theta_ccpw,sigma_ccp_w,beta,avRc,avRnc,Fw,Fk,badobs);
cf3_justcw 		= LRE(theta_justcw,sigma_ccp_w,beta,avRc,avRnc,Fw,Fk,badobs);
cf3_partialw	= LRE(theta_partialw,sigma_part_w,beta,avRc,avRnc,Fw,Fk,badobs);



%cf3_ccpws 		= LRE(theta_ccpws,sigma_ccp_ws_field,beta,avRc,avRnc,Fw,Fk);
%cf3_justcws 	= LRE(theta_justcws,sigma_ccp_ws_field,beta,avRc,avRnc,Fw,Fk);
%cf3_partialws	= LRE(theta_partialws,sigma_part_ws_field,beta,avRc,avRnc,Fw,Fk);


disp('LRE - NO SLOPE');
cf3_ccpw
cf3_justcw
cf3_partialw
%disp('LRE - SLOPE');
%cf3_ccpws
%cf3_justcws
%cf3_partialws


%------------------ Save results ---------------------------------------



sigma_stats  = [sigma_ccp_w,sigma_ccp_w_025,sigma_ccp_w_975,sqrt(vcmat_ccp_sigma)];
theta0_ccp_stats = [mean(theta_ccpw); theta0_025_ccp; theta0_975_ccp; se_theta0_ccp']';
theta0_hybrid_stats = [mean(theta_justcw); theta0_025_hybrid; theta0_975_hybrid; se_theta0_hybrid']';


outCF = [cf2_ccpw, cf2_justcw, cf2_partialw, ...
		cf3_ccpw, cf3_justcw, cf3_partialw];


outfile1 = [outfolder, 'cf.grid', num2str(g), '.ccp', num2str(cp), '.soil', num2str(soil), '.vdep', num2str(vdep), '.acres', num2str(acres), '.hdum', num2str(hdum), '.hz', num2str(hz), '.py', num2str(pyear), '.iv', num2str(ivspec), '.con', num2str(constant),'.ser', num2str(ser), '.csv'];
csvwrite(outfile1,outCF);

outfile2 = [outfolder, 'sigma.grid', num2str(g), '.ccp', num2str(cp), '.soil', num2str(soil), '.vdep', num2str(vdep), '.acres', num2str(acres), '.hdum', num2str(hdum), '.hz', num2str(hz), '.py', num2str(pyear), '.iv', num2str(ivspec), '.con', num2str(constant),'.ser', num2str(ser), '.csv'];
csvwrite(outfile2,sigma_stats);

outfile3 = [outfolder, 'theta0_ccp.grid', num2str(g), '.ccp', num2str(cp), '.soil', num2str(soil), '.vdep', num2str(vdep), '.acres', num2str(acres), '.hdum', num2str(hdum), '.hz', num2str(hz), '.py', num2str(pyear), '.iv', num2str(ivspec), '.con', num2str(constant),'.ser', num2str(ser), '.csv'];
csvwrite(outfile3,theta0_ccp_stats);

outfile4 = [outfolder, 'theta0_hybrid.grid', num2str(g), '.ccp', num2str(cp), '.soil', num2str(soil), '.vdep', num2str(vdep), '.acres', num2str(acres), '.hdum', num2str(hdum), '.hz', num2str(hz), '.py', num2str(pyear), '.iv', num2str(ivspec), '.con', num2str(constant),'.ser', num2str(ser), '.csv'];
csvwrite(outfile4,theta0_hybrid_stats);


toc

%outsuf = ['.grid', num2str(g), '.ccp', num2str(cp), '.soil', num2str(soil), '.vdep', num2str(vdep), '.acres', num2str(acres), '.hdum', num2str(hdum), '.hz', num2str(hz), '.py', num2str(pyear), '.iv', num2str(ivspec), '.con', num2str(constant), '.csv'];
%csvwrite([outfolder, 'sh_ccp', outsuf],	sig_hist_ccp_w);
%csvwrite([outfolder, 'sh_v', outsuf],		sig_hist_v_w);
%csvwrite([outfolder, 'sh_joint', outsuf],	sig_hist_joint_w);
%csvwrite([outfolder, 'sh_part', outsuf],	sig_hist_part_w);
%csvwrite([outfolder, 'sh_ccps', outsuf],	sig_hist_ccp_ws);
%csvwrite([outfolder, 'sh_vs', outsuf],		sig_hist_v_ws);
%csvwrite([outfolder, 'sh_joints', outsuf],	sig_hist_joint_ws);
%csvwrite([outfolder, 'sh_parts', outsuf],	sig_hist_part_ws);

% end
