

# replication for Identification of Counterfactuals by
# Kalouptsidi, Scott, and Souza-Rodrigues
# this script calls (in order) all programs used to prepare the data,
# run the estimation, and produce the tables and figures
# the very last file should be run manuall in Mathematica

# --------------------------

# Files not directly called below:

# spatial_merge.R - called by merge_spatial.sh
# fns_spatial_merge.R - called by spatial_merge.R
# firststage_semip.do - called by firststage.sh, CCP estimation
# firststage_hedonics.do - called by firststage.sh, hedonic estimation
# grids.do - called by runMatlabPrep.sh
# tomatlab.do - called by runMatlabPrep.sh
# runSS.m - called by runSecondStage.sh
# EstimateProfit.m - called by runSS.m, estimates payoff function

# files called by EstimateProfit.m:
# LRE.m - long-run elasticity
# LRmu.m - long-run distribution of field states
# EntryTax.m - performs entry tax counterfactual
# RotSub.m - performs fertilizer tax counterfactual
# getavres.m - average residuals
# interceptSE.m - compute standard errors on intercept
# sampleMVNormal.m - sample multivariate normal
# recover_intercepts.m called by interceptSE.m
# calcG.m - derivatives of moments
# calcS_alt.m - asymptotic variance
# calcS3.m - with clustering
# gmm_avar.m - sandwich formula
# twostage_gmm.m -does two-step gmm
# gmm_obj_full.m - gmm objective function
# viter.m - iterate value function
# solve_v.m - solve value function by iterating


# --------------------------


# basic DataQuick data cleaning -- this operates on confidential data
# output are of form processed/dq_cleanedi.dta
nohup stata -b do merge_dq.do > /dev/null 2>&1


# get lists of points from DQ data we want to obtain spatial data for
# output are of form spatial_data/targetxyi.csv
nohup stata -b do target_coordinates.do > /dev/null 2>&1


# --------------------------

# This will merge all of the spatial data.
# The primary program here is spatial_merge.R
# constructs panel of CDL data
# output is like outputi.csv
sh merge_spatial.sh


# --------------------------


# Merge spatial and land value data
stata -b do merge_all.do
# output is of form merging/merged_data.dta


# clean up the merged data, construct field state variables
stata -b do clean_data.do
# output in form Data/clean_data.dta


# get commercial data for grocery, restaurants
stata -b do commercial_properties.do


# find nearest cities, nearest commercial properties above a cutoff
Rscript urban_pop_nearest.R

# bring commercial info into main data
stata -b do commercial_merge.do


# bring city info into main data
stata -b do urban_pop_merge.do
# saves clean_data_all.dta

# --------------------------
# fill in missing zip codes
# probably needed
Rscript zip_codes.R
stata -b do add_zip.do
# saves clean_data_all.dta


# new definition of field state (not used in final results)
stata -b do newk.do


# --------------------------


# grab auxiliary data for grid of points from Scott (2013)
sh merge_spatial_ccp.sh
sh cleanup_spatial_ccp.sh

# combine data from previous spatial merges
stata -b do gather_cdl.do

# prepare data for CCP estimation
stata -b do ccp_points.do


# add commercial data for ccp grid points
Rscript ccp_commercial.R
Rscript ccp_commercial2.R
Rscript ccp_urban.R

# add zip codes
Rscript zip_codes_ccp.R


# add zips, commercial to ccp data
stata -b do ccp_data.do


# final data preparation: create some new measures of development pressure,
stata -b do final_prep.do

# cross-county weights for smoothing CCP estimates
stata -b do county_weights.do


# END DATA PREPARATION
# --------------------------

# firststage CCP estimation and hedonics
sh firststage.sh



# prep data for analysis in matlab
# fill in fitted CCPS, hedonics for points being used
# create ECCP dependent variables
# grids.do outputs grid...dta files
# tomatlab outputs estimation_data.grid...csv files
sh runMatlabPrep.sh



# second stage: estimate payoff function
sh runSecondStage.sh


# prepare results for tables
matlab -nodesktop -nodisplay  -nosplash -nojvm -r make_table



# --------------------------
# generate table selection.tex: looking for selection in dataquick sample
# the selection_clean.tex table in the paper just deletes some of the rows
# for variables that we're not interested in
stata -b do selection.do



# --------------------------
# to make tables and figures, Stats.nb run interactively in Mathematica
# outputs theta_table_ci.tex, cf_table.tex, vsum.tex, static_comp.tex
