function G = calcG(theta,xccp,xvc,xvnc,zccp,zvc,zvnc,wt,slope,est,spec)
% Calculate the Derivatives of Moment Conditions
% Inputs:
% theta = value of parameters
% data  = xccp,zccp,xvc,xvnc,zvc,zvnc
% wt    = weigths for observations
% slope = slope variable
% est   = select moment restrictions 
% -est       = 1 is CCP
% -est       = 2 is V
% -est       = 3 is joint
% -est       = 4 is partial
% spec       = select model:
% -spec      = 1 uses no slope
% -spec      = 2 uses slope
%
% Output:
% G = Derivatives of Moments Conditions

% Number of Obs
N = size(xccp,1);

% Model with no slope
if spec == 1	
    % CCP moment derivatives
	G1 = - zccp'*(xccp.*wt(:,ones(size(xccp,2),1)))/N;
    % VFN moment derivatives 
	G2 = zvc' *(xvc.*wt(:,ones(size(xvc,2),1)))/theta^2/N;
	G3 = zvnc'*(xvnc.*wt(:,ones(size(xvnc,2),1)))/theta^2/N;
end

% Model with slope
if spec == 2
    % Sigma
    sigma = exp(theta(1) + theta(2)*slope);
    % CCP moment derivatives
	dx = [xccp./sigma xccp./sigma.*slope];
	G1 = zccp'*(dx.*wt(:,ones(size(dx,2),1)))/N;
	% VFN moment derivatives
	dxvc  = [-xvc.*sigma -xvc.*sigma.*slope];
	G2    = zvc'*(dxvc.*wt(:,ones(size(dxvc,2),1)))/N;
	dxvnc = [-xvnc.*sigma -xvnc.*sigma.*slope];
	G3    = zvnc'*(dxvnc.*wt(:,ones(size(dxvnc,2),1)))/N;
end

if est == 1
	G = G1;
elseif est == 2
	G = [G2, G3];
elseif est ==3
	G = [G1;G2;G3];
elseif est ==4
	G = [G1;G2];
end
