function S = calcS2(z,eps,fid,k,year,wt,keep,TT)
% Asymptotic variance estimate of parameters, clustered by year 

% Number of Obs, Moment Restrictions
[NN K] = size(z);
N = sum(keep,1);

% Weights
wt(keep == 0) = 0;

% Temp
temp = [fid k year keep wt eps z];

% Sort data by year, k, fid
temp = sortrows(temp,[3,2,1]);

% Convert to array indexed by fid-k,year
temp_a = reshape(temp,[NN/TT,TT,6+K]);

% Make sure residuals are zero for ommitted observations
keep_a   = temp_a(:,:,4);
wt_a   = temp_a(:,:,5);
eps_a   = temp_a(:,:,6);
z_a      = temp_a(:,:,7:(6+K));
keepaa   = keep_a(:,:,ones(K,1));
eps_a(keep_a == 0) = 0;
z_a(keepaa == 0) = 0;

% (Weighted) Moment Restriction
eps_a = eps_a.*wt_a;

% Var-Cov Matrix clustered by year
S = zeros(K,K);
for t = 1:TT
	z_t   = reshape(z_a(:,t,:),NN/TT,K);
	eps_t = reshape(eps_a(:,t,:),NN/TT,1);
	S = S + (z_t'*eps_t)*(eps_t'*z_t);
end

S = S/(N-1);

