
library(foreach)
library(doParallel)

#setup parallel backend to use 4 processors
cl<-makeCluster(4)
registerDoParallel(cl)

list.types <- c("food","eat")  
crs_string <- "+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0"

main.folder <- "/home/landvalues/"
commercial.folder <- "/home/landvalues/commercial/"

# -------------------
# the nearest 5 commercial properties to each sample property

foreach(i=1:2) %dopar% {
	type = list.types[i]
	library(geosphere)  # For uniform random sampling on sphere
	library(maptools)
	library(raster)
	library(rgdal)
	# library(rgeos)

#	print(paste("finding nearest properties within",type))
	ccp.file <- paste(main.folder, "ccp_points.csv", sep="")
	c.file <- paste(commercial.folder, type, "_properties.csv", sep="") 
	output.file <- paste(commercial.folder, "ccp_commercial_", type, ".csv", sep="")

	ccpdata <- read.csv(ccp.file, header=TRUE)
	fid = ccpdata$fid

	cdata <- read.csv(c.file, header=TRUE)
	loglv = cdata$loglv
	loglv2 = cdata$loglv2

	coords <- c("lon", "lat")  # Column names
	cpts  <- SpatialPointsDataFrame(coords=cdata[, coords],
								   data=as.data.frame(cdata[, coords]),  # Unused
								   proj4string=CRS(crs_string))	
	ccppts <- SpatialPointsDataFrame(coords=ccpdata[, coords],
								   data=as.data.frame(ccpdata[, coords]),  # Unused
								   proj4string=CRS(crs_string))

	nearest <- sapply(seq_along(ccppts), function(i) {
		dists <- spDistsN1(cpts, ccppts[i, ], longlat=T)
		closest_pt <- which.min(dists)
		closest_pt2 <- which(dists == sort(dists,partial=2)[2]) # 2nd closest
		closest_pt3 <- which(dists == sort(dists,partial=3)[3])	# 3rd closest...
		closest_pt4 <- which(dists == sort(dists,partial=4)[4])
		closest_pt5 <- which(dists == sort(dists,partial=5)[5]) 
		return(c("closest_pt"=closest_pt, "distance_km1"=dists[closest_pt], "loglv_pt1"=loglv[closest_pt], "loglv2_pt1"=loglv2[closest_pt],
				"closest_pt2"=closest_pt2, "distance_km2"=dists[closest_pt2], "loglv_pt2"=loglv[closest_pt2], "loglv2_pt2"=loglv2[closest_pt2],
				"closest_pt3"=closest_pt3, "distance_km3"=dists[closest_pt3], "loglv_pt3"=loglv[closest_pt3], "loglv2_pt3"=loglv2[closest_pt3],
				"closest_pt4"=closest_pt4, "distance_km4"=dists[closest_pt4], "loglv_pt4"=loglv[closest_pt4], "loglv2_pt4"=loglv2[closest_pt4],
				"closest_pt5"=closest_pt5, "distance_km5"=dists[closest_pt5], "loglv_pt5"=loglv[closest_pt5], "loglv2_pt5"=loglv2[closest_pt5]
				))
	})		
					   
	nearest <- as.data.frame(t(nearest))
	stopifnot(nrow(nearest) == nrow(ccppts))

	ccppts <- spCbind(ccppts, nearest)
	ccppts$fid = fid

	write.csv(ccppts@data, file=output.file, row.names=FALSE)
}	


