
library(foreach)
library(doParallel)

#setup parallel backend to use 4 processors
cl<-makeCluster(4)
registerDoParallel(cl)

list.cutoffs <- c("1k","5k","10k","25k","50k","100k","500k")  
crs_string <- "+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0"

main.folder <- "/home/landvalues/"
urban_pop.folder <- "/home/landvalues/urban/"

# -------------------
# the nearest 3 urban areas above a population cutoff to each sample property

foreach(i=1:length(list.cutoffs)) %dopar% {
	cutoff = list.cutoffs[i]
	library(geosphere)  # For uniform random sampling on sphere
	library(maptools)
	library(raster)
	library(rgdal)
	# library(rgeos)

	print(paste("finding nearest urban area with population above", cutoff))	
	ccp.file <- paste(main.folder, "ccp_points.csv", sep="")
	c.file <- paste(urban_pop.folder, "urban_", cutoff, ".csv", sep="")
	output.file <- paste(urban_pop.folder, "ccp_urban_", cutoff, ".csv", sep="")

	ccpdata <- read.csv(ccp.file, header=TRUE)
	fid = ccpdata$fid

	cdata <- read.csv(c.file, header=TRUE)
	pop = cdata$population

	coords <- c("lon", "lat")  # Column names
	cpts  <- SpatialPointsDataFrame(coords=cdata[, coords],
								   data=as.data.frame(cdata[, coords]),  # Unused
								   proj4string=CRS(crs_string))	
	ccppts <- SpatialPointsDataFrame(coords=ccpdata[, coords],
								   data=as.data.frame(ccpdata[, coords]),  # Unused
								   proj4string=CRS(crs_string))

	nearest <- sapply(seq_along(ccppts), function(i) {
		dists <- spDistsN1(cpts, ccppts[i, ], longlat=T)
		closest_pt <- which.min(dists)
		closest_pt2 <- which(dists == sort(dists,partial=2)[2]) # 2nd closest
		closest_pt3 <- which(dists == sort(dists,partial=3)[3])	# 3rd closest		
		return(c("closest_pt"=closest_pt, "distance_km1"=dists[closest_pt], "pop_pt1"=pop[closest_pt], 
				"closest_pt2"=closest_pt2, "distance_km2"=dists[closest_pt2], "pop_pt2"=pop[closest_pt2],
				"closest_pt3"=closest_pt3, "distance_km3"=dists[closest_pt3], "pop_pt3"=pop[closest_pt3]
				))
	})		
					   
	nearest <- as.data.frame(t(nearest))
	stopifnot(nrow(nearest) == nrow(ccppts))

	ccppts <- spCbind(ccppts, nearest)
	ccppts$fid = fid

	write.csv(ccppts@data, file=output.file, row.names=FALSE)
}

