
set more off

local mainfolder = "/home/landvalues/"
local commercialfolder = "/home/landvalues/commercial/"


* --------------------------------------------------------------------------------------
* Commercial properties

local cutvals = "8k 32k 128k 512k"

insheet using "`commercialfolder'nearest_eat.csv", clear
rename closest_pt closest_pt1
forvalues i = 1/5 {
	rename closest_pt`i' closest_eat`i'
	rename distance_km`i' dist_eat`i'
	rename loglv_pt`i' loglv_eat`i'
	rename loglv2_pt`i' loglvB_eat`i'
}
save temp, replace

foreach x in `cutvals' {
	insheet using "`commercialfolder'nearest_eat_`x'.csv", clear
	rename closest_pt closest_pt1
	forvalues i = 1/3 {
		rename closest_pt`i' closest_eat`i'_`x'
		rename distance_km`i' dist_eat`i'_`x'
		rename loglv_pt`i' loglv_eat`i'_`x'
		rename loglv2_pt`i' loglvB_eat`i'_`x'
	}
	merge 1:1 dqid using temp
	drop _merge
	save temp, replace
}

insheet using "`commercialfolder'nearest_food.csv", clear
rename closest_pt closest_pt1
forvalues i = 1/5 {
	rename closest_pt`i' closest_food`i'
	rename distance_km`i' dist_food`i'
	rename loglv_pt`i' loglv_food`i'
	rename loglv2_pt`i' loglvB_food`i'
}
merge 1:1 dqid using temp
drop _merge
save temp, replace

foreach x in `cutvals' {
	insheet using "`commercialfolder'nearest_food_`x'.csv", clear
	rename closest_pt closest_pt1
	forvalues i = 1/3 {
		rename closest_pt`i' closest_food`i'_`x'
		rename distance_km`i' dist_food`i'_`x'
		rename loglv_pt`i' loglv_food`i'_`x'
		rename loglv2_pt`i' loglvB_food`i'_`x'
	}
	merge 1:1 dqid using temp
	drop _merge
	save temp, replace
} 

use "`mainfolder'clean_data.dta", clear 
merge m:1 dqid using temp
keep if _merge==3
drop _merge


save "`mainfolder'clean_data_commercial.dta", replace

* --------------------------------------------------------------------------------------
* average commercial LV by zip

use "`commercialfolder'eat_properties.dta", clear
gen lvpa = exp(loglv)
collapse (mean) lvpa, by(zip)
rename lvpa vmean_eat
save "`commercialfolder'vmean_eat.dta", replace

use "`commercialfolder'food_properties.dta", clear
gen lvpa = exp(loglv)
collapse (mean) lvpa, by(zip)
rename lvpa vmean_food
save "`commercialfolder'vmean_food.dta", replace

use "`mainfolder'clean_data_commercial.dta"
merge m:1 zip using "`commercialfolder'vmean_eat.dta"
drop if _merge==2
drop _merge
merge m:1 zip using "`commercialfolder'vmean_food.dta"
drop if _merge==2
drop _merge

save "`mainfolder'clean_data_commercial.dta", replace

