
set more off

local mainfolder = "/home/landvalues/"
local dqfolder = "/home/landvalues/dataquick/"
local spatialfolder = "/home/landvalues/spatial_data/"
local mergedfolder = "/home/landvalues/merging/"
local commercialfolder = "/home/landvalues/commercial/"

* -----------------------------------------------
* land value properties
use "`mainfolder'clean_data.dta", clear
tostring dqid, replace
contract dqid lon lat
drop _freq
drop if lat==. | lon==.
outsheet using "`mainfolder'v_points.csv", names comma replace


* -----------------------------------------------
* food store properties

forvalues c = 1/2 {
if `c'==1 {
	local name = "food"
	local dqcat = "CFOO"
}
if `c'==2 {
	local name = "eat"
	local dqcat = "CEAT"
}

clear
gen dqid = ""
save "`commercialfolder'`name'_properties.dta", replace
forvalues i = 0/9 {
	use "`dqfolder'processed/assessor`i'.dta", clear
	keep if use_code== "`dqcat'"
	append using "`commercialfolder'`name'_properties.dta"
	save "`commercialfolder'`name'_properties.dta", replace
}

destring assessedmarketlandvalue, force replace
destring lotsize, force replace
gen acres = lotsize/43560
gen lvpa = assessedmarketlandvalue/acres
gen logacres = log(acres)
gen loglv = log(lvpa)

* another version corrected for lot size
reg loglv logacres
local beta = _b[logacres]
gen loglv2 = loglv - `beta'*logacres

gen fips = stfips*1000 + cofips
keep dqid fips zip loglv loglv2

forvalues j=1/26 {
	merge m:1 dqid using "`spatialfolder'coordinates`j'.dta", update
	drop if _merge==2
	drop _merge
}

* keep centroid and address-level
keep if geoqlty ==0 | geoqlty==1

* drop zero land values
drop if loglv ==.

* if there are properties with identical coordinates, keep only one (there are very few such cases)
bysort lat lon: keep if _n==_N

* fix sign of longitude
destring lon lat, replace

replace lon = -lon
save "`commercialfolder'`name'_properties.dta", replace
outsheet using "`commercialfolder'`name'_properties.csv", comma replace
outsheet using "`commercialfolder'`name'_properties_1k.csv" if loglv >= log(1000), comma replace
outsheet using "`commercialfolder'`name'_properties_2k.csv" if loglv >= log(2000), comma replace
outsheet using "`commercialfolder'`name'_properties_4k.csv" if loglv >= log(4000), comma replace
outsheet using "`commercialfolder'`name'_properties_8k.csv" if loglv >= log(8000), comma replace
outsheet using "`commercialfolder'`name'_properties_16k.csv" if loglv >= log(16000), comma replace
outsheet using "`commercialfolder'`name'_properties_32k.csv" if loglv >= log(32000), comma replace
outsheet using "`commercialfolder'`name'_properties_64k.csv" if loglv >= log(64000), comma replace
outsheet using "`commercialfolder'`name'_properties_128k.csv" if loglv >= log(128000), comma replace
outsheet using "`commercialfolder'`name'_properties_256k.csv" if loglv >= log(256000), comma replace
outsheet using "`commercialfolder'`name'_properties_512k.csv" if loglv >= log(512000), comma replace
outsheet using "`commercialfolder'`name'_properties_1024k.csv" if loglv >= log(1024000), comma replace 

}

