
set more off

local datafolder = "/home/landvalues/"
local outfolder = "/home/landvalues/ccp/"


local fstlist = "4  5  8  10  13  16  17  18  19  20  21  22  24  27  28  29  30  31  32  34  36  37  38  39  40  41  42  45  47  48  49  53  55  56"

use "`datafolder'ccpdata_final.dta", clear
replace fipsstate = 24 if fipsstate == 10 /* delaware with maryland */
replace fipsstate = 27 if fipsstate == 38 /* nd with minnesota */
replace fipsstate = 30 if fipsstate == 16 /* idaho and montana */
replace fipsstate = 22 if fipsstate == 28 | fipsstate==5 /* arkansas, louisiana, and mississippi */
replace fipsstate = 39 if fipsstate == 21 /* kentucky and ohio */
replace fipsstate = 17 if fipsstate == 18 | fipsstate==55 /* illinois, indiana and wisconsin */
replace fipsstate = 19 if fipsstate == 31 /* nebraska and iowa */
replace fipsstate = 53 if fipsstate == 41 /* oregon and washington */
replace fipsstate =  8 if fipsstate == 56 /* colorado and wyoming */


save "`datafolder'ccpdata_pooled.dta", replace

local fstlist = "4  8  13  17  19  20  22  24  27  29  30  32  34  36  37  39  40  42  45  47  48  49  53"


foreach st in `fstlist' {
	use "`datafolder'ccpdata_pooled.dta", clear

	keep if fipsstate == `st'
	drop _freq
	collapse lat lon, by(fips)
	order fips lat lon
	sort fips
	gen ifips = _n
	save fips_temp, replace

	gen ones = 1
	drop fips
	reshape wide lat lon, i(ones) j(ifips)
	save temp_transpose, replace

	use fips_temp, clear
	gen ones = 1
	merge m:1 ones using temp_transpose
	drop _merge

	* distances between zips
	su ifips
	local imax = r(max)
	forvalues i=1/`imax' {
		gen dlon = (lon`i' - lon)
		gen dlat = (lat`i' - lat)
		gen a = (sin(dlat/2*_pi/180))^2 + cos(lat*_pi/180) * cos(lat`z'*_pi/180) * (sin(dlon*_pi/180/2))^2
		gen d`i' = 6373 * 2 * atan2( sqrt(a), sqrt(1-a) )
		drop dlon dlat a
	}
	drop lat* lon*


	* weights between counties
	forvalues i=1/`imax' {
		gen w`i' = 1/(1+d`i'/2)^2
	*	replace w`i' = 0 if d`i' >= 160
	}

	* total weights by counties
	forvalues i=1/`imax' {
		egen tw`i' = total(w`i')
	}

	* normalize weights
	* forvalues i=1/`imax' {
	* 	replace w`i' = w`i'/tw`i'
	* }

	* transpose so that target county is in a row, comparison county are columns
	keep fips ifips w*
	reshape long w, i(fips) j(compindex)
	rename ifips z
	rename compindex ifips
	drop fips
	reshape wide w, i(ifips) j(z)

	* put fips codes back in, save
	merge 1:1 ifips using fips_temp
	drop _merge
	order fips ifips lat lon
	sort fips
	save "`datafolder'fips_wts`st'.dta", replace
}
