* V-method for estimating profit function
set more off
set matsize 800

local beta = .9

global vdep = XXvdepXX
global acres = XXacresXX
global hdum = XXhdumXX
global hz = XXhzXX
global plantingYear = XXpyearXX

local datafolder = "/home/landvalues/"
local outfolder = "/home/landvalues/output/"

*local tempfolder = "C:/Users/Paul/Desktop/temp/"
*local datafolder = "F:/Dropbox/land_values/Data/"
*local outfolder = "F:/Dropbox/land_values/Output/"

local stlist = "4  5  8  10  12  13  16  17  18  19  20  21  22  24  27  28  29  30  31  32  34  36  37  38  39  40  41  42  45  47  48  49  53  55  56"


* variables that control specification
if missing("$acres") {
    global acres = 1
}
local acres = $acres

if missing("$vdep") {
    global vdep = 1
}
local vdep = $vdep

if missing("$hdum") {
    global hdum = 1
}
local hdum = $hdum

if missing("$hz") {
    global hz = 1
}
local hz = $hz

if missing("$plantingYear") {
    global plantingYear = 1
}
local plantingYear = $plantingYear

* set dependent variable
if ($vdep==1) {
    local ydep = "lvpa"
}
if ($vdep==2) {
    local ydep = "ltv"
}

* incude acres on RHS or not
if ($acres==1) { 
	local vacres = " "
}
if ($acres==2) {
	local vacres = "lacres"
}

* dependent variables for hedonics: linear
if ($hz==1) { 
	local zvars = "  ldist_100k mval_eat slope alt i.k##i.year c.Rcrop##i.year c.Rnocrop##i.year dsoil*"
}
* dependent variables for hedonics: quadratic
if ($hz==2) {
	local zvars =  " Rcrop2 Rnocrop2 ldist_100k mval_eat slope lmval2 slope2 lmvalslope alt i.k##i.year c.Rcrop##i.year c.Rnocrop##i.year dsoil*"
}

* which dummy variables to include
if ($hdum==1) { 
	local dummies = "fips"
}
if ($hdum==2) {
	local dummies = "zip"
}

log using "`outfolder'vlog.vdep`vdep'.acres`acres'.hdum`hdum'.hz`hz'.py`plantingYear'.txt", text replace


* --------------------------------------------------


use "`datafolder'vdata_final.dta", clear

* planting year vs. transfer year
gen transfer_year = year
if ($plantingYear == 2) {
	* set year
	replace year = year-1 if month<=4

	* set current variables
	replace currentj = . if month<=4
	replace currentk = . if month<=4

	forvalues y = 2008/2013 {
		replace currentj = j`y' if month<=4 & year==`y'
		replace currentk = k`y' if month<=4 & year==`y'
	}

}


merge m:1 year fips using "`datafolder'r_long.dta"
keep if _merge==3
drop _merge
rename r Rcrop
merge m:1 year fips using "`datafolder'r_with_pasture_long.dta"
keep if _merge==3
drop _merge
rename r Rdif
gen Rnocrop = Rcrop - Rdif

merge m:1 fips using  "`datafolder'r.dta"
keep if _merge==3
drop _merge
 forvalues y = 1997/2013 {
	rename r`y' rcrop`y'
}
merge m:1 fips using  "`datafolder'r_with_pasture.dta"
keep if _merge==3
drop _merge
 forvalues y = 1997/2013 {
	gen rnocrop`y' = rcrop`y' - r`y'
	drop r`y'
}

gen tv = v*acres

* selection criteria: drop non-standard transactions and outliers
keep if assessedmarketvalue == assessedmarketlandvalue
keep if multi==0
keep if trust==0 | trust ==.
keep if no_money==1 | no_money==.
keep if ownertype == 0 | ownertype==.
keep if v<=50000
keep if tv<10^7
keep if tv>60
bysort fips: gen nobs = _N
drop if nobs==1

gen ltv = log(v*acres)
gen lvpa = log(v)
gen lacres = log(acres)


gen Rcrop_saved = Rcrop
gen Rnocrop_saved = Rnocrop
gen currentk_saved = currentk


capture drop slope2
gen Rcrop2 = Rcrop^2
gen Rnocrop2 = Rnocrop^2 
gen lmval2 = mval_eat^2
gen slope2 = slope^2 
gen lmvalslope = mval_eat*slope

capture drop dsoil*
 forvalues i = 1/33 {
	gen dsoil`i' = (soil==`i')
}

gen fy = year+1
gen fk = .
replace fk = 0 if currentj == 1
replace fk = currentk+1 if currentj == 0
replace fk = 2 if fk>=2

gen fRcrop = .
gen fRnocrop = .
 forvalues y = 2008/2013 {
	replace fRcrop = rcrop`y' if fy==`y'
	replace fRnocrop = rnocrop`y' if fy==`y'
}

gen lvpahat = .
gen vpahat = .
gen flvpahat = .
gen fvpahat = .

rename currentk k

* set panel
xtset `dummies' saleid

* RUN REGRESSION
*xtreg `ydep' `zvars' `vacres', fe r
areg `ydep' `zvars' `vacres', absorb(`dummies') r
outreg2 using "`outfolder'hedonics.vdep`vdep'.acres`acres'.hdum`hdum'.hz`hz'.py`plantingYear'.tex", replace tex(frag) addnote(Soil and county dummies omitted.)

save "`outfolder'hedonics_data.vdep`vdep'.acres`acres'.hdum`hdum'.hz`hz'.py`plantingYear'.dta", replace
estimates save "`outfolder'hedonics.vdep`vdep'.acres`acres'.hdum`hdum'.hz`hz'.py`plantingYear'.ster", replace

log close

