
set more off

global ccp = XXccpXX
global soil = XXsoilXX

*local datafolder = "F:/Dropbox/land_values/Data/"
*local outfolder = "F:/Dropbox/land_values/Output/"
*local tempfolder = "C:/Users/ptscott/Desktop/temp/"
*local statecodes = "F:/Dropbox/land_values/data/state_codes.dta"

local datafolder = "/home/landvalues/"
local ccpfolder = "/home/landvalues/ccp/"
local outfolder = "/home/landvalues/output/"


* these variables control the specification initialize them
if missing("$ccp") {
    global ccp = 2
}
if missing("$soil") {
    global soil = 1
}

* which covariates to use
if ($ccp == 1) {
	local zvars1 = " "
	local zvars2 = " "
}
if ($ccp == 2) {
	local zvars1 = "slope"
	local zvars2 = "slope"
}
if ($ccp == 3) {
	local zvars1 = "ldist_100k mval_eat slope alt"
	local zvars2 = "ldist_100k slope"
}

local ccp = $ccp
local soil = $soil

log using "`outfolder'ccplog.ccp`ccp'.soil`soil'.txt", text replace


* ------------------------------------------
local stlist = "al az ar ca co de fl ga id il in ia ks ky la md mi mn ms mo mt ne nv nj nm ny nc nd oh ok or pa sc sd tn tx ut wa wi wy"
local fstlist = "4  8  13  17  19  20  22  24  27  29  30  32  34  36  37  39  40  42  45  47  48  49  53"

if ($ccp <= 3) {
foreach st in `fstlist' {

	* get state fips code
   *use "`statecodes'", clear
   *keep if postal == "`st'"
   *su fips
   *local stfips = `r(mean)'

	use "`datafolder'ccpdata_pooled.dta", clear
	
	drop dsoil*
	forvalues i = 1/33 {
		gen dsoil`i' = (soil==`i')
	}

	merge m:1 fips using "`ccpfolder'fips_wts`st'.dta"
	keep if _merge==3
	drop _merge
	
	* find the first year with non-missing k
	local y1 = 2010
	count if k2009!=. & k2009!=0
	if (`r(N)'!=0) {
		local y1 = 2009
	}
	count if k2008!=. & k2008!=0
	if (`r(N)'!=0) {
		local y1 = 2008
	}
	
	forvalues y = `y1'/2014 {
	forvalues k = 0/2 {
		gen phat_y`y'k`k' = .
	}
	}
	
	* count the number of counties
	su ifips
	local zmax = r(max)
	
	* local logit regression for each county and year
	forvalues z = 1/`zmax' {
		* weights for the appropriate county
		gen wt =  w`z'
		gen fwt =  round(w`z'*10000)
		forvalues y = `y1'/2014 {
			forvalues k=0/2 {
				display "`st'"
				display `z'
				display `y'
				display `k'
				

				* include soil dummies if there is more than one soil type
				if ($soil == 2) {
					capture confirm variable dsoil2
					if !_rc {
						local soilvars = "dsoil* "
					}
					else {
						local soilvars = " "	
					}
				}
				else {
					local soilvars = " "
				}

				capture logit j`y' `zvars1' `soilvars' [iw = wt] if k`y'==`k', iter(20)
				if !_rc {
					if (`e(converged)'!=1) {
						display "logit did not converge, starting firthlogit"
						* firthlogit requires we deal with collinearity manually
					 	_rmcoll `zvars1' `soilvars' if k`y'==`k', forcedrop
						capture firthlogit j`y' `r(varlist)' [fw = fwt] if k`y'==`k', iter(20)
						if (`e(converged)'!=1) {
							display "trying again..."
							_rmcoll `zvars1' if k`y'==`k', forcedrop
							capture firthlogit j`y' `r(varlist)' [fw = fwt] if k`y'==`k', iter(20)
							if (`e(converged)'!=1) {
								display "one last time..."
								_rmcoll `zvars2' if k`y'==`k', forcedrop
								capture firthlogit j`y' `r(varlist)' [fw = fwt] if k`y'==`k', iter(20)
								if (`e(converged)'!=1) {
									display "WARNING! firthlogit did not converge"
								}
							}
						}
					}
					estimates save "`outfolder'ccp/estimates.ccp`ccp'.soil`soil'.s`st'.z`z'.y`y'.k`k'.ster", replace

				}
			}
		}
		drop wt fwt
	}
}
}


if ($ccp == 4) {
	use "`datafolder'ccpdata_pooled.dta", clear
	forvalues y = 2008/2014 {
		forvalues k=0/2 {
			logit j`y' ldist_100k mval_eat slope alt dsoil* i.fipsstate if k`y'==`k', iter(40)
			if (`e(converged)'!=1) {
				firthlogit j`y' ldist_100k mval_eat slope alt dsoil* i.fipsstate if k`y'==`k'
			}
			estimates save "`outfolder'ccp/estimates.ccp`ccp'.soil`soil'.y`y'.k`k'.ster", replace
		}
	}
}
if ($ccp == 5) {
	use "`datafolder'ccpdata_pooled.dta", clear
	forvalues y = 2008/2014 {
		logit j`y' i.k`y'##c.slope ldist_100k mval_eat alt dsoil* i.fipsstate, iter(40)
		if (`e(converged)'!=1) {
			firthlogit j`y' i.k`y'##c.slope ldist_100k mval_eat alt dsoil* i.fipsstate
		}
		estimates save "`outfolder'ccp/estimates.ccp`ccp'.soil`soil'.y`y'.ster", replace
	}
}

log close

