## Author: Adrian Torchiana (adrian.torchiana@gmail.com)
## RA work for Paul Scott (ptscott@gmail.com)

## Functions loaded by spatial_merge.R

aspect <- function(dz.dx, dz.dy) {
    stopifnot(length(dz.dx) == 1 && length(dz.dy) == 1)
    if (dz.dy == 0) {
        if (dz.dx == 0) return(NA)
        return(pi * (1.5 - 1*(dz.dx < 0)))
    }
    aspect <- atan(dz.dx / dz.dy)
    return(aspect + (dz.dy > 0) * pi + (dz.dy < 0 && dz.dx >0)*2*pi)
}

closest.srid.naive <- function(i) {
    ## Calculate all distances between dq.pts[i, ] and wg.pts
    dists <- spDistsN1(pts=wg.pts, pt=dq.pts[i, ])
    return(wg$srid[which.min(dists)])
}

closest.srid.analytical <- function(lat, lon, lat.on.grid=39.625, lon.on.grid=-99.5, grid.delta=1/24) {
    ## Careful, can return a nonexistent srid if nearest.grid.{lat,lon} is e.g. in a lake and not part of wg
    dlat <- (lat - lat.on.grid) %% grid.delta
    dlon <- (lon - lon.on.grid) %% grid.delta
    nearest.grid.lat <- lat - dlat + ifelse(dlat < 0.5*grid.delta, 0, grid.delta)
    nearest.grid.lon <- lon - dlon + ifelse(dlon < 0.5*grid.delta, 0, grid.delta)
    return(srid.from.lat.lon(nearest.grid.lat, nearest.grid.lon))
}

get.raster.variable <- function(filename) {
    message("Loading ", filename)
    raster.object <- raster(filename)
    dq.pts.reproj <- spTransform(dq.pts, CRS(projection(raster.object)))  # Extract fn does this internally with warning
    extracted.variable <- extract(raster.object, dq.pts.reproj)
    stopifnot(length(extracted.variable) == nrow(dq.pts))
    return(extracted.variable)
}

srid.from.lat.lon <- function(lat, lon) {
    ## Uses formula from http://www.wolfram-schlenker.com/dailyData/dataDescription.pdf
    ## j = ceiling(srid / 1405); k = mod(srid - 1, 1404)
    j <- 24 * (49.9375 + 1/48 - lat)
    k <- 24 * (125 + lon)
    return(as.integer(round((j - 1) * 1405 + k + 1)))
}
