function objval = gmm_obj_full(theta,dyccp,dyvc,dyvnc,dr,xxvc,xxvnc,z1,z2,z3,W,wt,slope,est,spec)
% GMM Criterion Function
% Inputs:
% theta = value of parameters
% data  = dyccp,dyvc,dyvnc,dr,xxvc,xxvnc,z1,z2,z3,
% W     = GMM Weighting matrix
% wt    = weigths for observations
% slope = slope variable
% est   = select moment restrictions 
% (est = 1 is CCP; est = 2 is V; est = 3 is joint; est = 4 is partial)
% spec  = select model,
% (spec = 1 is no slope; spec = 2 is slope)
%
% Output:
% objval = Value of the GMM criterion function


% Number of obs
N = size(dyccp,1);

% Sum of weights
Nw = sum(wt);

% Residual Function
if spec == 1
	sigma = 1/(theta);
	eps1 = dyccp - dr/sigma;
	eps2 = dyvc  - xxvc  * sigma;
	eps3 = dyvnc - xxvnc * sigma;
end
if spec == 2 
	sigma = exp(theta(1) + theta(2)*slope);
	eps1  = dyccp - dr./sigma;
	eps2  = dyvc  - xxvc  .* sigma;
	eps3  = dyvnc - xxvnc .* sigma;
end

% Moment Restrictions
g1 = z1'*(eps1.*wt)/Nw;
g2 = z2'*(eps2.*wt)/Nw;
g3 = z3'*(eps3.*wt)/Nw;

% Select Moment Restrictions
if est == 1
	g = g1;
elseif est ==2
	g = [g2;g3];
elseif est ==3
	g = [g1;g2;g3];
elseif est ==4
	g = [g1;g2];
end

% Value of the GMM Criterion Function
objval = g'*W*g;
if isnan(objval)
	objval = 10^16
end


















