set more off
set matsize 800

global ccp = XXccpXX
global soil = XXsoilXX
global vdep = XXvdepXX
global acres = XXacresXX
global hdum = XXhdumXX
global hz = XXhzXX
global plantingYear = XXpyearXX
global grid = XXgridXX

local datafolder = "/home/landvalues/"
local outfolder = "/home/landvalues/output/"

*local tempfolder = "C:/Users/ptscott/Desktop/temp/"
*local datafolder = "F:/Dropbox/land_values/Data/"
*local outfolder = "F:/Dropbox/land_values/Output/"

local stlist = "4  5  8  10  12  13  16  17  18  19  20  21  22  24  27  28  29  30  31  32  34  36  37  38  39  40  41  42  45  47  48  49  53  55  56"
local fstlist = "4  8  13  17  19  20  22  24  27  29  30  32  34  36  37  39  40  42  45  47  48  49  53"

local betadiscount = .95

* variables which control the specification
if missing("$ccp") {
    global ccp = 2
}

if missing("$soil") {
    global soil = 1
}

if missing("$acresRHS") {
    global acresRHS = 1
}

if missing("$totalPrice") {
    global totalPrice = 1
}

if missing("$acres") {
    global acres = 1
}

if missing("$vdep") {
    global vdep = 1
}

if missing("$hdum") {
    global hdum = 1
}

if missing("$hz") {
    global hz = 1
}

if missing("$plantingYear") {
    global plantingYear = 1
}

if missing("$grid") {
    global grid = 1
}

local ccp = $ccp
local soil = $soil
local acres = $acres
local vdep = $vdep
local hdum = $hdum
local hz = $hz
local plantingYear = $plantingYear
local grid = $grid

log using "log.grid`grid'.ccp`ccp'.soil`soil'.vdep`vdep'.acres`acres'.hdum`hdum'.hz`hz'.py`plantingYear'.txt", text replace

* ----------------------------------------------------------------
* CCP predictions and construction of FULL GRID

if ($grid == 1) {
	* load the data that was used to estimate CCP's 
	use "`datafolder'ccpdata_pooled.dta", clear
}
if ($grid == 2) {
	* load the data set used to do hedonics
	use "`outfolder'hedonics_data.vdep`vdep'.acres`acres'.hdum`hdum'.hz`hz'.py`plantingYear'.dta", clear
	rename stfips fipsstate
}

 forvalues y = 2008/2014 {
	forvalues k=0/2 {
		gen phat`y'_k`k' = .
	}
}

* create soil dummies
capture drop dsoil*
 forvalues i = 1/33 {
	gen dsoil`i' = (soil==`i')
}

* fill in CCP estimates
if ($ccp <= 3) {
foreach st in `fstlist' {
	merge m:1 fips using "`datafolder'ccp/fips_wts`st'.dta"
	drop _merge
	su ifips
	local zmax = r(max)
	
	forvalues z = 1/`zmax' {
		gen wt =  w`z'
		gen fwt =  round(w`z'*10000)
		forvalues y = 2008/2014 {
			forvalues k=0/2 {
				capture estimates use "`outfolder'ccp/estimates.ccp`ccp'.soil`soil'.s`st'.z`z'.y`y'.k`k'.ster"
				if !_rc {
					predict phat_temp, xb
					replace phat`y'_k`k' = exp(phat_temp)/(1 + exp(phat_temp)) if ifips == `z' & fipsstate==`st'
					drop phat_temp
				}

			}
		}
		drop wt fwt
	}
	drop w* ifips
}
}

if ($ccp ==4) {
	forvalues y = 2008/2014 {
		forvalues k=0/2 {
			capture estimates use "`outfolder'ccp/estimates.ccp`ccp'.soil`soil'.y`y'.k`k'.ster"
			if !_rc {
				predict phat_temp, xb
				replace phat`y'_k`k' = exp(phat_temp)/(1 + exp(phat_temp))
				drop phat_temp
			}
		}
	}
}

 forvalues y = 2008/2014 {
	capture rename k`y' k`y'saved
}

if ($ccp ==5) {
	forvalues y = 2008/2014 {
		capture estimates use "`outfolder'ccp/estimates.ccp`ccp'.soil`soil'.y`y'.ster"
		if !_rc {
			forvalues k = 0/2 {
				gen k`y' = `k'
				predict phat_temp, xb
				replace phat`y'_k`k' = exp(phat_temp)/(1 + exp(phat_temp))
				drop phat_temp
				drop k`y'
			}
		}
	}
}

 forvalues y = 2008/2014 {
	capture k`y'saved rename k`y'
}

* Drop fields where we don't have a prediction from 2010 onward
 forvalues y = 2010/2013 {
	forvalues k=0/2 {
		drop if phat`y'_k`k' == .
	}
}

* add sample sizes to data: these will be used to construct weights
merge m:1 fips using "`datafolder'sample_sizes.dta"
 keep if _merge==3
 drop _merge


* create dependent variable for CCP-based estimation, observation weights
 forvalues y = 2008/2013 {
	local fy = `y' + 1
	forvalues k = 0/2 {
		local fk = `k' + 1
		if `k'==2 {
			local fk = 2
		}
		* dependent variable
		gen y_k`k'_`y' = log(phat`y'_k`k'/(1-phat`y'_k`k')) + `betadiscount'*log(phat`fy'_k0/phat`fy'_k`fk')
		* create weights
		gen pmin_k`k'_`y' = min(phat`y'_k`k',1-phat`y'_k`k',phat`fy'_k0,phat`fy'_k`fk')
		replace pmin_k`k'_`y' = max(pmin_k`k'_`y',.0001)
		gen wt_k`k'_`y' = d`y'_k`k'*pmin_k`k'_`y'/(1 - pmin_k`k'_`y')
	}
}

* add returns
capture drop r2006-r2013
merge m:1 fips using "`datafolder'r.dta"
keep if _merge==3
drop _merge
drop r1997-r2005 
renvarlab r2006-r2013, presub("r" "Rcrop")
merge m:1 fips using "`datafolder'r_with_pasture.dta"
keep if _merge==3
drop _merge
drop r1997-r2005 
renvarlab r2006-r2013, presub("r" "Rdif")
forvalues y = 2006/2013 {
	gen Rnocrop`y' = Rcrop`y' - Rdif`y'
}

* make sure this works on CCP data set! then re-run matlab prep for CCP case
capture drop slope2 lmval2 lmvalslope
gen lmval2 = mval_eat^2
gen slope2 = slope^2 
gen lmvalslope = mval_eat*slope

* add value function predictions
estimates use "`outfolder'hedonics.vdep`vdep'.acres`acres'.hdum`hdum'.hz`hz'.py`plantingYear'.ster"
if ($vdep == 1) {
	local ydep = "lvpa"
}
if ($vdep == 2) {
	local ydep = "ltv"
}


if ($grid==1) {
	gen acres = 100
	gen lacres = log(acres)
}

if ($grid==2) {
	rename k currentk
	rename Rcrop cRcrop
	rename Rnocrop cRnocrop
	rename year cyear
	drop Rcrop2 Rnocrop2
}

gen k = .
gen year = .
gen Rcrop = .
gen Rnocrop = .
gen Rcrop2 = .
gen Rnocrop2 = .
forvalues y = 2008/2013 {
	replace Rcrop = Rcrop`y'
	replace Rnocrop = Rnocrop`y'
	replace Rcrop2 = Rcrop^2
	replace Rnocrop2 = Rnocrop^2
	replace k = 0
	replace year = `y'
	predict `ydep'hat`y'_k0

	replace k = 1
	predict `ydep'hat`y'_k1
		
	replace k = 2
	predict `ydep'hat`y'_k2
}

if ($vdep == 2) {
	forvalues y = 2008/2013 {
		gen lvpahat`y'_k0 = log(exp(`ydep'hat`y'_k0)/acres)
		gen lvpahat`y'_k1 = log(exp(`ydep'hat`y'_k1)/acres)
		gen lvpahat`y'_k2 = log(exp(`ydep'hat`y'_k2)/acres)
	}
}

drop k Rcrop Rnocrop acres lacres

merge m:1 fips using "`datafolder'cy.dta"
keep if _merge==3
drop _merge

save "`outfolder'grid`grid'.ccp`ccp'.soil`soil'.vdep`vdep'.acres`acres'.hdum`hdum'.hz`hz'.py`plantingYear'.dta",replace

log close

