* This file merges assessor information, transaction information, and
* various spatial data.
* ptscott, July 2014

* test

* local dqfolder = "E:/DataQuick/"
* local spatialfolder = "E:/spatial_data/centroids/"
* local mergedfolder = "E:/spatial_data/merged/"

local mainfolder = "/home/landvalues/"
local dqfolder = "/home/landvalues/dataquick/"
local spatialfolder = "/home/landvalues/spatial_data/"
local mergedfolder = "/home/landvalues/merging/"

* ----------------------------------------
* clean up assessor data

forvalues i = 0/9 {
	use "`dqfolder'processed/assessor`i'.dta", clear

	foreach x in assessmentyear assessmenttaxvalue assessmenttaxlandvalue assessmenttaximprovmentvalue assessedmarketvalue ///
	assessedmarketlandvalue assessedmarketimprovementvalue cashsale lotsize sruniqueid transactiondate transactionsaleamount ///
	disabledexemption_amt seniorexemption_amt veteranexemption_amt widowexemption_amt otherexemption_amt {
		capture destring `x', force replace
	}

	keep dqid stfips cofips owner trust ownertype use_code ///
	housenumber housefraction street streetsuffix city state  zip zipplus4 ///
	assessmentyear assessmenttaxvalue assessmenttaxlandvalue assessmenttaximprovmentvalue ///
	assessedmarketvalue assessedmarketlandvalue assessedmarketimprovementvalue ///
	cashsale lotsize sruniqueid transactiondate transactionsaleamount ///
	disabledexemption disabledexemption_amt seniorexemption seniorexemption_amt ///
	veteranexemption veteranexemption_amt widowexemption widowexemption_amt otherexemption otherexemption_amt ///
	township_as range_as section_as quarter_as tract_as unit_as

	order dqid stfips cofips owner trust ownertype use_code ///
	housenumber housefraction street streetsuffix city state zip zipplus4 ///
	assessmentyear assessmenttaxvalue assessmenttaxlandvalue assessmenttaximprovmentvalue ///
	assessedmarketvalue assessedmarketlandvalue assessedmarketimprovementvalue ///
	cashsale lotsize sruniqueid transactiondate transactionsaleamount ///
	disabledexemption disabledexemption_amt seniorexemption seniorexemption_amt ///
	veteranexemption veteranexemption_amt widowexemption widowexemption_amt otherexemption otherexemption_amt ///
	township_as range_as section_as quarter_as tract_as unit_as

	save "`dqfolder'processed/cleaned_assessor`i'.dta", replace
}

* ----------------------------------------
* combine history and assessor and do some preliminary cleaning


forvalues i = 0/9 {
	use "`dqfolder'processed/history`i'.dta", clear

	keep transid dqid state stfips cofips transfer_val transfer_tax transfer_date transfer_filing transaction_type  ///
	partial_flag partial_interest multiple_parcels transaction_quit_claim no_money distress ///
	range section subdiv township tract unit buyer seller siteaddr mailaddr ///
	mailnum mailfrac mailstreet mailsuf mailunittype mailunitnum mailcity mailstate mailzip mailzipp4


	* drop transactions which are non-standard
	drop if partial_flag=="P" | partial_flag=="U"
	drop if partial_interest=="X" | partial_interest=="P"
*	drop if multiple_parcels=="M"
*	keep if transaction_type=="R"

	* drop if transaction price does not look like a real sale
	destring transfer_val, force replace
	drop if transfer_val<=1
	drop if transfer_val==.

	* get coordinates
	forvalues j=1/26 {
		merge m:1 dqid using "`spatialfolder'coordinates`j'.dta", update
		drop if _merge==2
		drop _merge
	}

	* add assessor data
	forvalues j=0/9 {
		merge m:1 dqid using "`dqfolder'processed/cleaned_assessor`j'.dta", update
		drop if _merge==2
		drop _merge
	}

	destring transfer_date, replace
	gen transfer_year = floor(transfer_date/10000)

	* clean land values that exceed property value
	* there are rare cases where assessed land value exceeds property value -- clean these up
	gen assessedmarketvalue2 = assessedmarketimprovementvalue + assessedmarketlandvalue
	replace assessedmarketvalue = assessedmarketvalue2 if assessedmarketvalue2!=.

	* % of assessment that is land value
	gen percentland = assessedmarketlandvalue/assessedmarketvalue
	gen resaleprice = percentland*transfer_val

	* measure price in $/acre
	gen acres = lotsize/43560
	gen resalepricefinal = resaleprice/acres

	* assessed market value per acre is sometimes useful to look at
	gen va = assessedmarketvalue/acres
	gen vla = assessedmarketlandvalue/acres

	* keep if DQ's use code indicates that it might potentially be agricultural land
	keep if substr(use_code,1,1)=="A" | use_code=="VAGR" | use_code=="VMSC"

	* drop very small properties
	drop if acres < 1

	* drop missing data
	drop if missing(resalepricefinal)

	save "`dqfolder'processed/dq_cleaned`i'.dta", replace

}

* ----------------------------------------
* combine the files

use "`dqfolder'processed/dq_cleaned0.dta", clear

forvalues i = 1/9 {
	append using "`dqfolder'processed/dq_cleaned`i'.dta"

}

save "`dqfolder'processed/dq_cleaned.dta", replace
