

local datafolder = "F:/Dropbox/land_values/Data/"
local outfolder = "F:/Dropbox/land_values/Output/"

use "`datafolder'vdata_final.dta", clear

gen tv = v*acres
* selection criteria: drop non-standard transactions and outliers
keep if assessedmarketvalue == assessedmarketlandvalue
keep if multi==0
keep if trust==0 | trust ==.
keep if no_money==1 | no_money==.
keep if ownertype == 0 | ownertype==.
keep if v<=50000
keep if tv<10^7
keep if tv>60
bysort fips: gen nobs = _N
drop if nobs==1

* collapse data by field, with indicators for whether each field was transacted each year
* do this for both the regular year definition and planting year definition

forvalues y = 2008/2014 {
	gen soldin`y' = year==`y'
	gen soldinp`y' = pyear==`y'
}

collapse (mean) j* k* ldist_100k mval_eat slope alt soil multi trust no_money ownertype v (max) soldin*, by(dqid fips zip)

merge m:1 fips using  "`datafolder'r.dta"
keep if _merge==3
drop _merge
 forvalues y = 1997/2013 {
	rename r`y' rcrop`y'
}
merge m:1 fips using  "`datafolder'r_with_pasture.dta"
keep if _merge==3
drop _merge
 forvalues y = 1997/2013 {
	gen rnocrop`y' = rcrop`y' - r`y'
	drop r`y'
}
 forvalues y = 1997/2013 {
	gen dr`y' = rcrop`y' -  rnocrop`y'
}

gen stfips = floor(fips/1000)

* 2013
areg j2013 soldin2013 i.k2010##c.slope c.dr2010##c.slope ldist_100k mval_eat, absorb( stfips)
areg j2013 soldinp2013 i.k2010##c.slope c.dr2010##c.slope ldist_100k mval_eat, absorb( stfips)

* significant, positive without restricting sample
areg j2013 soldin2012 i.k2010##c.slope c.dr2010##c.slope ldist_100k mval_eat, absorb( stfips)
* significant, negative without restricting sample
areg j2013 soldinp2014 i.k2010##c.slope c.dr2010##c.slope ldist_100k mval_eat, absorb( stfips)

* 2012
areg j2012 soldin2012 i.k2010##c.slope c.dr2010##c.slope ldist_100k mval_eat, absorb( stfips)
areg j2012 soldinp2012 i.k2010##c.slope c.dr2010##c.slope ldist_100k mval_eat, absorb( stfips)
areg j2012 soldin2011 i.k2010##c.slope c.dr2010##c.slope ldist_100k mval_eat, absorb( stfips)
areg j2012 soldinp2013 i.k2010##c.slope c.dr2010##c.slope ldist_100k mval_eat, absorb( stfips)

* 2011
areg j2011 soldin2011 i.k2010##c.slope c.dr2010##c.slope ldist_100k mval_eat, absorb( stfips)
* significant, positive with and without restricting sample
areg j2011 soldinp2011 i.k2010##c.slope c.dr2010##c.slope ldist_100k mval_eat, absorb( stfips)
areg j2011 soldin2010 i.k2010##c.slope c.dr2010##c.slope ldist_100k mval_eat, absorb( stfips)
areg j2011 soldinp2012 i.k2010##c.slope c.dr2010##c.slope ldist_100k mval_eat, absorb( stfips)

* 2010
areg j2010 soldin2010 i.k2010##c.slope c.dr2010##c.slope ldist_100k mval_eat, absorb( stfips)
areg j2010 soldinp2010 i.k2010##c.slope c.dr2010##c.slope ldist_100k mval_eat, absorb( stfips)
areg j2010 soldin2009 i.k2010##c.slope c.dr2010##c.slope ldist_100k mval_eat, absorb( stfips)
areg j2010 soldinp2011 i.k2010##c.slope c.dr2010##c.slope ldist_100k mval_eat, absorb( stfips)



* for table in paper
areg j2010 soldin2009 soldin2010 soldin2011 i.k2010##c.slope c.dr2010##c.slope ldist_100k mval_eat, absorb( stfips)
outreg2 using "`outfolder'selection.tex", replace tex(frag)
areg j2011 soldin2010 soldin2011 soldin2012 i.k2011##c.slope c.dr2011##c.slope ldist_100k mval_eat, absorb( stfips)
outreg2 using "`outfolder'selection.tex", append tex(frag)
areg j2012 soldin2011 soldin2012 soldin2013 i.k2012##c.slope c.dr2012##c.slope ldist_100k mval_eat, absorb( stfips)
outreg2 using "`outfolder'selection.tex", append tex(frag)
areg j2013 soldin2012 soldin2013            i.k2013##c.slope c.dr2013##c.slope ldist_100k mval_eat, absorb( stfips)
outreg2 using "`outfolder'selection.tex", append tex(frag)
