
set more off
set matsize 800

global ccp = XXccpXX
global soil = XXsoilXX
global vdep = XXvdepXX
global acres = XXacresXX
global hdum = XXhdumXX
global hz = XXhzXX
global plantingYear = XXpyearXX
global grid = XXgridXX

local datafolder = "/home/landvalues/output/"
local outfolder = "/data/landvalues/interim/"

* local tempfolder = "C:/Users/ptscott/Desktop/temp/"
* local datafolder = "F:/Dropbox/land_values/Data/"
* local outfolder = "F:/Dropbox/land_values/Output/"

local stlist = "4  5  8  10  12  13  16  17  18  19  20  21  22  24  27  28  29  30  31  32  34  36  37  38  39  40  41  42  45  47  48  49  53  55  56"
local fstlist = "4  8  13  17  19  20  22  24  27  29  30  32  34  36  37  39  40  42  45  47  48  49  53"

local eulergamma = 0.5772156649
local beta = 0.95

* variables which control the specification
if missing("$ccp") {
    global ccp = 3
}

if missing("$soil") {
    global soil = 1
}

if missing("$acresRHS") {
    global acresRHS = 1
}

if missing("$totalPrice") {
    global totalPrice = 1
}

if missing("$acres") {
    global acres = 1
}

if missing("$vdep") {
    global vdep = 1
}

if missing("$hdum") {
    global hdum = 1
}

if missing("$hz") {
    global hz = 1
}

if missing("$plantingYear") {
    global plantingYear = 1
}

if missing("$grid") {
    global grid = 1
}

local ccp = $ccp
local soil = $soil
local vdep = $vdep
local acres = $acres
local hdum = $hdum
local hz = $hz
local plantingYear = $plantingYear
local grid = $grid

if ($grid ==1) {
	local panelvar = "fid"
}
if ($grid ==2) {
	local panelvar = "saleid"
}

log using "`outfolder'logmatlab.grid`grid'.ccp`ccp'.soil`soil'.vdep`vdep'.acres`acres'.hdum`hdum'.hz`hz'.py`plantingYear'.txt", text replace


use "`datafolder'grid`grid'.ccp`ccp'.soil`soil'.vdep`vdep'.acres`acres'.hdum`hdum'.hz`hz'.py`plantingYear'.dta", clear
capture drop lvpa lvpahat Rcrop_saved Rnocrop_saved
capture drop Rcrop_saved Rnocrop_saved
keep `panelvar' y_k*  lvpa* wt* Rcrop* Rnocrop* yield_kcal phat* slope fips

 forvalues y = 2008/2013 {
	rename lvpahat`y'_k0 lvk0_`y'
	rename lvpahat`y'_k1 lvk1_`y'
	rename lvpahat`y'_k2 lvk2_`y'
}


 forvalues y = 2008/2012 {
	forvalues k = 0/2 {
		local fy = `y' + 1
		local fk = `k' + 1
		if `k' == 2 {
			local fk = 2
		}

		gen psicropk`k'_`y' = -log(phat`y'_k`k') + `eulergamma'
		gen psinocropk`k'_`y' = -log(1-phat`y'_k`k') + `eulergamma'	
	
		gen ynk`k'_`y' = exp(lvk`k'_`y') - `beta'*exp(lvk`k'_`fy')  - Rnocrop`y'
		gen yck`k'_`y' = exp(lvk`k'_`y') - `beta'*exp(lvk0_`fy') - Rcrop`y'
	}
}

drop lvk* phat*
reshape long Rcrop Rnocrop psicropk0_ psicropk1_ psicropk2_ psinocropk0_ psinocropk1_ psinocropk2_ y_k0_ y_k1_ y_k2_ ynk0_ ynk1_ ynk2_ yck0_ yck1_ yck2_ wt_k0_ wt_k1_ wt_k2_, i(`panelvar') j(year)

foreach var in psicropk0 psicropk1 psicropk2 psinocropk0 psinocropk1 psinocropk2 y_k0 y_k1 y_k2 ynk0 ynk1 ynk2 yck0 yck1 yck2 wt_k0 wt_k1 wt_k2 {
	rename `var'_ `var'
}

reshape long psicropk psinocropk y_k ynk yck wt_k, i(`panelvar' year) j(k)


rename psicropk psicrop
rename psinocropk psinocrop
rename y_k yccp
rename ynk yvn
rename yck yvc
rename wt_k wt 

egen fkid = group(`panelvar' k)
xtset fkid year
sort fkid year

gen Rdif = Rcrop - Rnocrop

sort fkid year
gen dyccp = yccp - L.yccp
gen dr = Rdif - L.Rdif
* gen lr = L.Rdif
gen dyvc = yvc - L.yvc
gen dyvn = yvn - L.yvn
gen dpsic = psicrop - L.psicrop
gen dpsin = psinocrop - L.psinocrop
gen lpsic = L.psicrop
gen lpsin = L.psinocrop
* gen l2r = L2.Rdif
gen l2psic = L2.psicrop
gen l2psin = L2.psinocrop

* import R in a way such that lags won't be missing
drop Rdif 
merge m:1 fips year using "`datafolder'Rdif_with_lags.dta"
keep if _merge==3
drop _merge

* add y's ccp's wts's 
local outvars = "dyccp dyvc dyvn dr lr dpsic dpsin lpsic lpsin yield_kcal `panelvar' k yccp yvc yvn psicrop psinocrop Rcrop Rnocrop year wt slope l2r l2psic l2psin fips"

order `outvars' 
outsheet `outvars' using "`outfolder'estimation_data.grid`grid'.ccp`ccp'.soil`soil'.vdep`vdep'.acres`acres'.hdum`hdum'.hz`hz'.py`plantingYear'.raw", nonames  replace

log close


*reg dr lr yield_kcal
*predict drhat
*reg dyccp drhat [aw = wt], noconstant
*reg dyccp drhat [aw = wt]
