# install.packages('geosphere')
# install.packages('maptools')
# install.packages('raster')
# install.packages('rgdal')
# install.packages('rgeos')

library(geosphere)  # For uniform random sampling on sphere
library(maptools)
library(raster)
library(rgdal)
# library(rgeos)

list.cutoffs <- c("1k","5k","10k","25k","50k","100k","500k")  

crs_string <- "+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0"

main.folder <- "/home/landvalues/"
urban_pop.folder <- "/home/landvalues/urban/"


# -------------------
# the nearest 3 urban areas above a populational cutoff to each sample property

for (cutoff in list.cutoffs){
	print(paste("finding nearest urban area with population above", cutoff))	
	v.file <- paste(main.folder, "v_points.csv", sep="")
	c.file <- paste(urban_pop.folder, "urban_", cutoff, ".csv", sep="")
	output.file <- paste(urban_pop.folder, "nearest_urban_", cutoff, ".csv", sep="")

	vdata <- read.csv(v.file, header=TRUE)
	dqid = vdata$dqid

	cdata <- read.csv(c.file, header=TRUE)
	pop = cdata$population

	coords <- c("lon", "lat")  # Column names
	cpts  <- SpatialPointsDataFrame(coords=cdata[, coords],
								   data=as.data.frame(cdata[, coords]),  # Unused
								   proj4string=CRS(crs_string))	
	vpts <- SpatialPointsDataFrame(coords=vdata[, coords],
								   data=as.data.frame(vdata[, coords]),  # Unused
								   proj4string=CRS(crs_string))

	nearest <- sapply(seq_along(vpts), function(i) {
		dists <- spDistsN1(cpts, vpts[i, ], longlat=T)
		closest_pt <- which.min(dists)
		closest_pt2 <- which(dists == sort(dists,partial=2)[2]) # 2nd closest
		closest_pt3 <- which(dists == sort(dists,partial=3)[3])	# 3rd closest		
		return(c("closest_pt"=closest_pt, "distance_km1"=dists[closest_pt], "pop_pt1"=pop[closest_pt], 
				"closest_pt2"=closest_pt2, "distance_km2"=dists[closest_pt2], "pop_pt2"=pop[closest_pt2],
				"closest_pt3"=closest_pt3, "distance_km3"=dists[closest_pt3], "pop_pt3"=pop[closest_pt3]
				))
	})		
					   
	nearest <- as.data.frame(t(nearest))
	stopifnot(nrow(nearest) == nrow(vpts))

	vpts <- spCbind(vpts, nearest)
	vpts$dqid = dqid

	write.csv(vpts@data, file=output.file, row.names=FALSE)
}

