function cv = vcond(theta,lambda,beta,r,Fw,Fk,V)
% calculate conditional value functions given ex ante value function
% cv is [X K J]

% INPUTS
% theta: [K J] intercept matrix
% lambda: scalar sensitivity parameter
% beta: scalar discount factor
%
% X: number of states
% r: [X K J] array of observable payoffs
% Fx: [X X] transition matrix
% Fk: [K K J] transition matrix
%
% V: [X 3] ex ante value function
% V(2 1) corresponds to V(x=2, k=0), V(a,b) corresponds to V(x=a,k=b-1)

X = size(r,1);
K=3;
J=2;
theta = reshape(theta,[1 K J]);

EV1 = Fw*V;

EV = zeros(X,K,J);

for j = 1:J
    EV(:,:,j) = (Fk(:,:,j)*EV1')';
end

cv = theta(ones(X,1),:,:) + lambda*r + beta * EV; 
